@@ -26,7 +26,7 @@ var _ = Describe("App Runner", func() {
 	BeforeAll(func() {
 		_, initErr = cli.Init(&client.InitRequest{
 			AppName:      appName,
-			WorkloadName: svcName,
+			WorkloadName: feSvcName,
 			ImageTag:     "gallopinggurdey",
 			Dockerfile:   "./front-end/Dockerfile",
 			WorkloadType: "Request-Driven Web Service",
@@ -57,7 +57,7 @@ var _ = Describe("App Runner", func() {
 
 		It("should return one service", func() {
 			Expect(len(svcList.Services)).To(Equal(1))
-			Expect(svcList.Services[0].Name).To(Equal(svcName))
+			Expect(svcList.Services[0].Name).To(Equal(feSvcName))
 			Expect(svcList.Services[0].AppName).To(Equal(appName))
 			Expect(svcList.Services[0].Type).To(Equal("Request-Driven Web Service"))
 		})
@@ -71,7 +71,7 @@ var _ = Describe("App Runner", func() {
 
 		BeforeAll(func() {
 			out, svcStatusError = cli.SvcStatus(&client.SvcStatusRequest{
-				Name:    svcName,
+				Name:    feSvcName,
 				AppName: appName,
 				EnvName: envName,
 			})
@@ -86,26 +86,60 @@ var _ = Describe("App Runner", func() {
 		})
 	})
 
-	Context("run storage init and svc deploy to create an S3 bucket", func() {
+	Context("run storage init and svc deploy to create an S3 bucket and an aurora DB", func() {
 		var (
-			storageInitErr error
-			deployErr      error
+			s3StorageInitErr error
+			auroraInitErr    error
+			deployErr        error
 		)
 
 		BeforeAll(func() {
-			_, storageInitErr = cli.StorageInit(&client.StorageInitRequest{
+			_, s3StorageInitErr = cli.StorageInit(&client.StorageInitRequest{
 				StorageName:  "s3storage",
 				StorageType:  "S3",
-				WorkloadName: svcName,
+				WorkloadName: feSvcName,
+			})
+			_, auroraInitErr = cli.StorageInit(&client.StorageInitRequest{
+				StorageName:   "front-end-cluster",
+				StorageType:   "Aurora",
+				WorkloadName:  feSvcName,
+				RDSEngine:     "PostgreSQL",
+				InitialDBName: "mydb",
 			})
 			_, deployErr = cli.SvcDeploy(&client.SvcDeployInput{
 				EnvName: envName,
-				Name:    svcName,
+				Name:    feSvcName,
 			})
 		})
 
 		It("should not return an error", func() {
-			Expect(storageInitErr).NotTo(HaveOccurred())
+			Expect(s3StorageInitErr).NotTo(HaveOccurred())
+			Expect(auroraInitErr).NotTo(HaveOccurred())
+			Expect(deployErr).NotTo(HaveOccurred())
+		})
+	})
+
+	Context("create and deploy a backend service", func() {
+		var (
+			initErr   error
+			deployErr error
+		)
+
+		BeforeAll(func() {
+			_, initErr = cli.SvcInit(&client.SvcInitRequest{
+				Name:       beSvcName,
+				SvcType:    "Backend Service",
+				Dockerfile: "./back-end/Dockerfile",
+				SvcPort:    "80",
+			})
+			_, deployErr = cli.SvcDeploy(&client.SvcDeployInput{
+				EnvName: envName,
+				Name:    beSvcName,
+			})
+		})
+
+		It("should not return an error", func() {
+			Expect(initErr).NotTo(HaveOccurred())
 			Expect(deployErr).NotTo(HaveOccurred())
 		})
 	})
@@ -118,7 +152,7 @@ var _ = Describe("App Runner", func() {
 
 		BeforeAll(func() {
 			svc, svcShowError = cli.SvcShow(&client.SvcShowRequest{
-				Name:      svcName,
+				Name:      feSvcName,
 				AppName:   appName,
 				Resources: true,
 			})
@@ -129,7 +163,7 @@ var _ = Describe("App Runner", func() {
 		})
 
 		It("should return correct configuration", func() {
-			Expect(svc.SvcName).To(Equal(svcName))
+			Expect(svc.SvcName).To(Equal(feSvcName))
 			Expect(svc.AppName).To(Equal(appName))
 			Expect(len(svc.Configs)).To(Equal(1))
 			Expect(svc.Configs[0].Environment).To(Equal(envName))
@@ -140,15 +174,16 @@ var _ = Describe("App Runner", func() {
 
 		It("should return correct environment variables", func() {
 			fmt.Printf("\n\nenvironment variables: %+v\n\n", svc.Variables)
-			Expect(len(svc.Variables)).To(Equal(4))
 			expectedVars := map[string]string{
-				"COPILOT_APPLICATION_NAME": appName,
-				"COPILOT_ENVIRONMENT_NAME": envName,
-				"COPILOT_SERVICE_NAME":     svcName,
-				"S3STORAGE_NAME":           "", // The value is unknown because it's autogenerated by CloudFormation.
+				"COPILOT_APPLICATION_NAME":           appName,
+				"COPILOT_ENVIRONMENT_NAME":           envName,
+				"COPILOT_SERVICE_NAME":               feSvcName,
+				"COPILOT_SERVICE_DISCOVERY_ENDPOINT": fmt.Sprintf("%s.%s.local", envName, appName),
+				"S3STORAGE_NAME":                     "", // The value is unknown because it's autogenerated by CloudFormation.
+				"FRONTENDCLUSTER_SECRET_ARN":         "", //same reason as above.
 			}
 			for _, variable := range svc.Variables {
-				if variable.Name == "S3STORAGE_NAME" {
+				if variable.Name == "S3STORAGE_NAME" || variable.Name == "FRONTENDCLUSTER_SECRET_ARN" {
 					Expect(variable.Value).NotTo(BeEmpty())
 					continue
 				}
@@ -159,11 +194,15 @@ var _ = Describe("App Runner", func() {
 		It("should return the correct resources", func() {
 			Expect(len(svc.Resources)).To(Equal(1))
 			Expect(svc.Resources[envName]).NotTo(BeNil())
-			Expect(len(svc.Resources[envName])).To(Equal(4))
 			expectedTypes := map[string]*countAssertionTracker{
-				"AWS::IAM::Role":             {2, 0},
-				"AWS::CloudFormation::Stack": {1, 0},
-				"AWS::AppRunner::Service":    {1, 0},
+				"AWS::IAM::Role":                 {3, 0},
+				"AWS::CloudFormation::Stack":     {1, 0},
+				"AWS::AppRunner::Service":        {1, 0},
+				"AWS::EC2::SecurityGroup":        {1, 0},
+				"AWS::EC2::SecurityGroupIngress": {1, 0},
+				"AWS::AppRunner::VpcConnector":   {1, 0},
+				"Custom::EnvControllerFunction":  {1, 0},
+				"AWS::Lambda::Function":          {1, 0},
 			}
 
 			for _, r := range svc.Resources[envName] {
@@ -180,45 +219,45 @@ var _ = Describe("App Runner", func() {
 			}
 		})
 
-		It("should return svc endpoints", func() {
+		It("should return svc endpoints and service discovery should work", func() {
 			Expect(len(svc.Routes)).To(Equal(1))
-			Expect(svc.Routes[0].Environment).To(Equal(envName))
-			Expect(svc.Routes[0].URL).NotTo(BeEmpty())
+			route := svc.Routes[0]
+			Expect(route.Environment).To(Equal(envName))
+			Expect(route.URL).NotTo(BeEmpty())
 			Eventually(func() (int, error) {
-				resp, fetchErr := http.Get(svc.Routes[0].URL)
+				resp, fetchErr := http.Get(route.URL)
+				return resp.StatusCode, fetchErr
+			}, "30s", "1s").Should(Equal(200))
+			Eventually(func() (int, error) {
+				resp, fetchErr := http.Get(fmt.Sprintf("%s/service-discovery-test/", route.URL))
+				return resp.StatusCode, fetchErr
+			}, "30s", "1s").Should(Equal(200))
+			Eventually(func() (int, error) {
+				resp, fetchErr := http.Get(fmt.Sprintf("%s/db/", route.URL))
 				return resp.StatusCode, fetchErr
 			}, "30s", "1s").Should(Equal(200))
 		})
 	})
 
-	Context("run svc logs to troubleshoot", func() {
-		var (
-			svcLogs    []client.SvcLogsOutput
-			svcLogsErr error
-		)
-
-		BeforeAll(func() {
+	It("svc logs should display logs", func() {
+		var svcLogs []client.SvcLogsOutput
+		var svcLogsErr error
+		Eventually(func() ([]client.SvcLogsOutput, error) {
 			svcLogs, svcLogsErr = cli.SvcLogs(&client.SvcLogsRequest{
 				AppName: appName,
-				Name:    svcName,
+				Name:    feSvcName,
 				EnvName: "test",
 				Since:   "1h",
 			})
-		})
+			return svcLogs, svcLogsErr
+		}, "60s", "10s").ShouldNot(BeEmpty())
 
-		It("should not return an error", func() {
-			Expect(svcLogsErr).NotTo(HaveOccurred())
-		})
-
-		It("should return valid log lines", func() {
-			Expect(len(svcLogs)).To(BeNumerically(">", 0))
-			for _, logLine := range svcLogs {
-				Expect(logLine.Message).NotTo(Equal(""))
-				Expect(logLine.LogStreamName).NotTo(Equal(""))
-				Expect(logLine.Timestamp).NotTo(Equal(0))
-				Expect(logLine.IngestionTime).NotTo(Equal(0))
-			}
-		})
+		for _, logLine := range svcLogs {
+			Expect(logLine.Message).NotTo(Equal(""))
+			Expect(logLine.LogStreamName).NotTo(Equal(""))
+			Expect(logLine.Timestamp).NotTo(Equal(0))
+			Expect(logLine.IngestionTime).NotTo(Equal(0))
+		}
 	})
 
 	Context("run pause and then resume the service", func() {
@@ -235,20 +274,20 @@ var _ = Describe("App Runner", func() {
 			_, svcPauseError = cli.SvcPause(&client.SvcPauseRequest{
 				AppName: appName,
 				EnvName: envName,
-				Name:    svcName,
+				Name:    feSvcName,
 			})
 			pausedSvcStatus, pausedSvcStatusError = cli.SvcStatus(&client.SvcStatusRequest{
-				Name:    svcName,
+				Name:    feSvcName,
 				AppName: appName,
 				EnvName: envName,
 			})
 			_, svcResumeError = cli.SvcResume(&client.SvcResumeRequest{
 				AppName: appName,
 				EnvName: envName,
-				Name:    svcName,
+				Name:    feSvcName,
 			})
 			resumedSvcStatus, resumedSvcStatusError = cli.SvcStatus(&client.SvcStatusRequest{
-				Name:    svcName,
+				Name:    feSvcName,
 				AppName: appName,
 				EnvName: envName,
 			})
@@ -280,11 +319,11 @@ var _ = Describe("App Runner", func() {
 		BeforeAll(func() {
 			_, svcDeployError = cli.SvcDeploy(&client.SvcDeployInput{
 				EnvName: envName,
-				Name:    svcName,
+				Name:    feSvcName,
 				Force:   true,
 			})
 			svcStatus, svcStatusError = cli.SvcStatus(&client.SvcStatusRequest{
-				Name:    svcName,
+				Name:    feSvcName,
 				AppName: appName,
 				EnvName: envName,
 			})
