@@ -7,6 +7,9 @@ import (
 	"errors"
 	"fmt"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/ssm"
+
 	"github.com/spf13/cobra"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
@@ -56,23 +59,20 @@ type initAppOpts struct {
 }
 
 func newInitAppOpts(vars initAppVars) (*initAppOpts, error) {
-	sess, err := sessions.NewProvider().Default()
+	sess, err := sessions.ImmutableProvider(sessions.UserAgentExtras("app init")).Default()
 	if err != nil {
 		return nil, fmt.Errorf("default session: %w", err)
 	}
-	store, err := config.NewStore()
-	if err != nil {
-		return nil, fmt.Errorf("new config store: %w", err)
-	}
 	ws, err := workspace.New()
 	if err != nil {
 		return nil, fmt.Errorf("new workspace: %w", err)
 	}
 
+	identity := identity.New(sess)
 	return &initAppOpts{
 		initAppVars:      vars,
-		identity:         identity.New(sess),
-		store:            store,
+		identity:         identity,
+		store:            config.NewSSMStore(identity, ssm.New(sess), aws.StringValue(sess.Config.Region)),
 		route53:          route53.New(sess),
 		domainInfoGetter: route53.NewRoute53Domains(sess),
 		ws:               ws,
@@ -134,13 +134,18 @@ https://aws.github.io/copilot-cli/docs/credentials/`)
 			return nil
 		}
 		if o.name != summary.Application {
+			summaryPath, _ := relPath(summary.Path)
+			if summaryPath == "" {
+				summaryPath = summary.Path
+			}
+
 			log.Errorf(`Workspace is already registered with application %s instead of %s.
-If you'd like to delete the application locally, you can remove the %s directory.
+If you'd like to delete the application locally, you can delete the file at %s.
 If you'd like to delete the application and all of its resources, run %s.
 `,
 				summary.Application,
 				o.name,
-				workspace.CopilotDirName,
+				summaryPath,
 				color.HighlightCode("copilot app delete"))
 			return fmt.Errorf("workspace already registered with %s", summary.Application)
 		}
