@@ -10,6 +10,8 @@ import (
 	"os"
 	"strings"
 
+	"github.com/aws/aws-sdk-go/service/ssm"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
@@ -139,9 +141,10 @@ type initEnvVars struct {
 	isProduction  bool   // True means retain resources even after deletion.
 	defaultConfig bool   // True means using default environment configuration.
 
-	importVPC importVPCVars // Existing VPC resources to use instead of creating new ones.
-	adjustVPC adjustVPCVars // Configure parameters for VPC resources generated while initializing an environment.
-	telemetry telemetryVars // Configure observability and monitoring settings.
+	importVPC   importVPCVars // Existing VPC resources to use instead of creating new ones.
+	adjustVPC   adjustVPCVars // Configure parameters for VPC resources generated while initializing an environment.
+	telemetry   telemetryVars // Configure observability and monitoring settings.
+	importCerts []string      // Addtional existing ACM certificates to use.
 
 	tempCreds tempCredsVars // Temporary credentials to initialize the environment. Mutually exclusive with the profile.
 	region    string        // The region to create the environment in.
@@ -173,15 +176,13 @@ type initEnvOpts struct {
 }
 
 func newInitEnvOpts(vars initEnvVars) (*initEnvOpts, error) {
-	store, err := config.NewStore()
-	if err != nil {
-		return nil, err
-	}
-	sessProvider := sessions.NewProvider()
+	sessProvider := sessions.ImmutableProvider(sessions.UserAgentExtras("env init"))
 	defaultSession, err := sessProvider.Default()
 	if err != nil {
 		return nil, err
 	}
+	store := config.NewSSMStore(identity.New(defaultSession), ssm.New(defaultSession), aws.StringValue(defaultSession.Config.Region))
+
 	cfg, err := profile.NewConfig()
 	if err != nil {
 		return nil, fmt.Errorf("read named profiles: %w", err)
@@ -262,7 +263,7 @@ func (o *initEnvOpts) Execute() error {
 		return fmt.Errorf("get identity: %w", err)
 	}
 
-	if app.RequiresDNSDelegation() {
+	if app.Domain != "" {
 		if err := o.delegateDNSFromApp(app, envCaller.Account); err != nil {
 			return fmt.Errorf("granting DNS permissions: %w", err)
 		}
@@ -294,9 +295,9 @@ func (o *initEnvOpts) Execute() error {
 	if err != nil {
 		return err
 	}
-	urls, err := o.uploader.UploadEnvironmentCustomResources(s3.CompressAndUploadFunc(func(key string, objects ...s3.NamedBinary) (string, error) {
+	urls, err := o.uploader.UploadEnvironmentCustomResources(func(key string, objects ...s3.NamedBinary) (string, error) {
 		return s3Client.ZipAndUpload(resources.S3Bucket, key, objects...)
-	}))
+	})
 	if err != nil {
 		return fmt.Errorf("upload custom resources to bucket %s: %w", resources.S3Bucket, err)
 	}
@@ -320,7 +321,14 @@ func (o *initEnvOpts) Execute() error {
 		return fmt.Errorf("get environment struct for %s: %w", o.name, err)
 	}
 	env.Prod = o.isProduction
-	env.CustomConfig = config.NewCustomizeEnv(o.importVPCConfig(), o.adjustVPCConfig())
+	customizedEnv := config.CustomizeEnv{
+		ImportVPC:      o.importVPCConfig(),
+		VPCConfig:      o.adjustVPCConfig(),
+		ImportCertARNs: o.importCerts,
+	}
+	if !customizedEnv.IsEmpty() {
+		env.CustomConfig = &customizedEnv
+	}
 	env.Telemetry = o.telemetry.toConfig()
 
 	// 6. Store the environment in SSM.
@@ -512,8 +520,7 @@ https://aws.amazon.com/premiumsupport/knowledge-center/ecs-pull-container-api-er
 		})
 		if err != nil {
 			if errors.Is(err, selector.ErrSubnetsNotFound) {
-				log.Warningf(`No existing subnets were found in VPC %s.
-If you proceed without at least two public subnets, you will not be able to deploy Load Balanced Web Services in this environment.
+				log.Warningf(`No existing public subnets were found in VPC %s.
 `, o.importVPC.ID)
 			} else {
 				return fmt.Errorf("select public subnets: %w", err)
@@ -522,6 +529,13 @@ If you proceed without at least two public subnets, you will not be able to depl
 		if len(publicSubnets) == 1 {
 			return errors.New("select public subnets: at least two public subnets must be selected to enable Load Balancing")
 		}
+		if len(publicSubnets) == 0 {
+			log.Warningf(`If you proceed without public subnets, you will not be able to deploy 
+Load Balanced Web Services in this environment, and will need to specify 'private' 
+network placement in your workload manifest(s). See the manifest documentation 
+specific to your workload type(s) (https://aws.github.io/copilot-cli/docs/manifest/overview/).
+`)
+		}
 		o.importVPC.PublicSubnetIDs = publicSubnets
 	}
 	if o.importVPC.PrivateSubnetIDs == nil {
@@ -532,18 +546,26 @@ If you proceed without at least two public subnets, you will not be able to depl
 			IsPublic: false,
 		})
 		if err != nil {
-			if err == selector.ErrSubnetsNotFound {
-				log.Errorf(`No existing subnets were found in VPC %s. You can either:
-- Create new private subnets and then import them.
-- Use the default Copilot environment configuration.`, o.importVPC.ID)
+			if errors.Is(err, selector.ErrSubnetsNotFound) {
+				log.Warningf(`No existing private subnets were found in VPC %s. 
+`, o.importVPC.ID)
+			} else {
+				return fmt.Errorf("select private subnets: %w", err)
 			}
-			return fmt.Errorf("select private subnets: %w", err)
 		}
-		if len(privateSubnets) < 2 {
+		if len(privateSubnets) == 1 {
 			return errors.New("select private subnets: at least two private subnets must be selected")
 		}
+		if len(privateSubnets) == 0 {
+			log.Warningf(`If you proceed without private subnets, you will not 
+be able to add them after this environment is created.
+`)
+		}
 		o.importVPC.PrivateSubnetIDs = privateSubnets
 	}
+	if len(o.importVPC.PublicSubnetIDs)+len(o.importVPC.PrivateSubnetIDs) == 0 {
+		return errors.New("VPC must have subnets in order to proceed with environment creation")
+	}
 	return nil
 }
 
@@ -569,7 +591,7 @@ func (o *initEnvOpts) askAdjustResources() error {
 		publicCIDR, err := o.prompt.Get(
 			envInitPublicCIDRPrompt, envInitPublicCIDRPromptHelp,
 			validatePublicSubnetsCIDR(len(o.adjustVPC.AZs)),
-			prompt.WithDefaultInput(stack.DefaultPublicSubnetCIDRs), prompt.WithFinalMessage("Public subnets CIDR:"))
+			prompt.WithDefaultInput(strings.Join(stack.DefaultPublicSubnetCIDRs, ",")), prompt.WithFinalMessage("Public subnets CIDR:"))
 		if err != nil {
 			return fmt.Errorf("get public subnet CIDRs: %w", err)
 		}
@@ -579,7 +601,7 @@ func (o *initEnvOpts) askAdjustResources() error {
 		privateCIDR, err := o.prompt.Get(
 			envInitPrivateCIDRPrompt, envInitPrivateCIDRPromptHelp,
 			validatePrivateSubnetsCIDR(len(o.adjustVPC.AZs)),
-			prompt.WithDefaultInput(stack.DefaultPrivateSubnetCIDRs), prompt.WithFinalMessage("Private subnets CIDR:"))
+			prompt.WithDefaultInput(strings.Join(stack.DefaultPrivateSubnetCIDRs, ",")), prompt.WithFinalMessage("Private subnets CIDR:"))
 		if err != nil {
 			return fmt.Errorf("get private subnet CIDRs: %w", err)
 		}
@@ -675,7 +697,7 @@ func (o *initEnvOpts) deployEnv(app *config.Application,
 		Name: o.name,
 		App: deploy.AppInformation{
 			Name:                o.appName,
-			DNSName:             app.Domain,
+			Domain:              app.Domain,
 			AccountPrincipalARN: caller.RootUserARN,
 		},
 		Prod:                 o.isProduction,
@@ -684,6 +706,7 @@ func (o *initEnvOpts) deployEnv(app *config.Application,
 		ArtifactBucketARN:    artifactBucketARN,
 		ArtifactBucketKeyARN: artifactBucketKeyARN,
 		AdjustVPCConfig:      o.adjustVPCConfig(),
+		ImportCertARNs:       o.importCerts,
 		ImportVPCConfig:      o.importVPCConfig(),
 		Telemetry:            o.telemetry.toConfig(),
 		Version:              deploy.LatestEnvTemplateVersion,
@@ -797,10 +820,11 @@ func buildEnvInitCmd() *cobra.Command {
   Creates a prod-iad environment using your "prod-admin" AWS profile and enables container insights.
   /code $ copilot env init --name prod-iad --profile prod-admin --container-insights
 
-  Creates an environment with imported VPC resources.
+  Creates an environment with imported resources.
   /code $ copilot env init --import-vpc-id vpc-099c32d2b98cdcf47 \
   /code --import-public-subnets subnet-013e8b691862966cf,subnet-014661ebb7ab8681a \
-  /code --import-private-subnets subnet-055fafef48fb3c547,subnet-00c9e76f288363e7f
+  /code --import-private-subnets subnet-055fafef48fb3c547,subnet-00c9e76f288363e7f \
+  /code --import-cert-arns arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012
 
   Creates an environment with overridden CIDRs and AZs.
   /code $ copilot env init --override-vpc-cidr 10.1.0.0/16 \
@@ -829,7 +853,7 @@ func buildEnvInitCmd() *cobra.Command {
 	cmd.Flags().StringVar(&vars.importVPC.ID, vpcIDFlag, "", vpcIDFlagDescription)
 	cmd.Flags().StringSliceVar(&vars.importVPC.PublicSubnetIDs, publicSubnetsFlag, nil, publicSubnetsFlagDescription)
 	cmd.Flags().StringSliceVar(&vars.importVPC.PrivateSubnetIDs, privateSubnetsFlag, nil, privateSubnetsFlagDescription)
-
+	cmd.Flags().StringSliceVar(&vars.importCerts, certsFlag, nil, certsFlagDescription)
 	cmd.Flags().IPNetVar(&vars.adjustVPC.CIDR, overrideVPCCIDRFlag, net.IPNet{}, overrideVPCCIDRFlagDescription)
 	cmd.Flags().StringSliceVar(&vars.adjustVPC.AZs, overrideAZsFlag, nil, overrideAZsFlagDescription)
 	// TODO: use IPNetSliceVar when it is available (https://github.com/spf13/pflag/issues/273).
@@ -851,7 +875,7 @@ func buildEnvInitCmd() *cobra.Command {
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(vpcIDFlag))
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(publicSubnetsFlag))
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(privateSubnetsFlag))
-
+	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(certsFlag))
 	resourcesConfigFlags := pflag.NewFlagSet("Configure Default Resources", pflag.ContinueOnError)
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overrideVPCCIDRFlag))
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overrideAZsFlag))
