@@ -8,13 +8,13 @@ import (
 	"io/ioutil"
 	"os"
 
-	"github.com/aws/copilot-cli/internal/pkg/describe"
-	"github.com/aws/copilot-cli/internal/pkg/exec"
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/ssm"
+	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/config"
-	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation"
-	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
+	"github.com/aws/copilot-cli/internal/pkg/exec"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
 	"github.com/aws/copilot-cli/internal/pkg/term/selector"
@@ -29,23 +29,23 @@ const (
 )
 
 type packageJobVars struct {
-	name      string
-	envName   string
-	appName   string
-	tag       string
-	outputDir string
+	name         string
+	envName      string
+	appName      string
+	tag          string
+	outputDir    string
+	uploadAssets bool
 }
 
 type packageJobOpts struct {
 	packageJobVars
 
 	// Interfaces to interact with dependencies.
-	ws              wsJobDirReader
-	store           store
-	runner          runner
-	sel             wsSelector
-	prompt          prompter
-	stackSerializer func(mft interface{}, env *config.Environment, app *config.Application, rc stack.RuntimeConfig) (stackSerializer, error)
+	ws     wsJobDirReader
+	store  store
+	runner runner
+	sel    wsSelector
+	prompt prompter
 
 	// Subcommand implementing svc_package's Execute()
 	packageCmd    actionCommand
@@ -53,19 +53,17 @@ type packageJobOpts struct {
 }
 
 func newPackageJobOpts(vars packageJobVars) (*packageJobOpts, error) {
+	sessProvider := sessions.ImmutableProvider(sessions.UserAgentExtras("job package"))
+	defaultSess, err := sessProvider.Default()
+	if err != nil {
+		return nil, err
+	}
+	store := config.NewSSMStore(identity.New(defaultSess), ssm.New(defaultSess), aws.StringValue(defaultSess.Config.Region))
+
 	ws, err := workspace.New()
 	if err != nil {
 		return nil, fmt.Errorf("new workspace: %w", err)
 	}
-	store, err := config.NewStore()
-	if err != nil {
-		return nil, fmt.Errorf("connect to config store: %w", err)
-	}
-	p := sessions.NewProvider()
-	sess, err := p.Default()
-	if err != nil {
-		return nil, fmt.Errorf("retrieve default session: %w", err)
-	}
 	prompter := prompt.New()
 	opts := &packageJobOpts{
 		packageJobVars: vars,
@@ -76,47 +74,28 @@ func newPackageJobOpts(vars packageJobVars) (*packageJobOpts, error) {
 		prompt:         prompter,
 	}
 
-	opts.stackSerializer = func(mft interface{}, env *config.Environment, app *config.Application, rc stack.RuntimeConfig) (stackSerializer, error) {
-		var serializer stackSerializer
-		jobMft := mft.(*manifest.ScheduledJob)
-		serializer, err := stack.NewScheduledJob(jobMft, env.Name, app.Name, rc)
-		if err != nil {
-			return nil, fmt.Errorf("init scheduled job stack serializer: %w", err)
-		}
-		return serializer, nil
-	}
-
 	opts.newPackageCmd = func(o *packageJobOpts) {
 		opts.packageCmd = &packageSvcOpts{
 			packageSvcVars: packageSvcVars{
-				name:      o.name,
-				envName:   o.envName,
-				appName:   o.appName,
-				tag:       imageTagFromGit(o.runner, o.tag),
-				outputDir: o.outputDir,
+				name:         o.name,
+				envName:      o.envName,
+				appName:      o.appName,
+				tag:          imageTagFromGit(o.runner, o.tag),
+				outputDir:    o.outputDir,
+				uploadAssets: o.uploadAssets,
 			},
 			runner:           o.runner,
 			initAddonsClient: initPackageAddonsClient,
 			ws:               ws,
 			store:            o.store,
-			appCFN:           cloudformation.New(sess),
 			stackWriter:      os.Stdout,
+			unmarshal:        manifest.UnmarshalWorkload,
 			newInterpolator:  newManifestInterpolator,
 			paramsWriter:     ioutil.Discard,
 			addonsWriter:     ioutil.Discard,
 			fs:               &afero.Afero{Fs: afero.NewOsFs()},
-			stackSerializer:  o.stackSerializer,
-			newEndpointGetter: func(app, env string) (endpointGetter, error) {
-				d, err := describe.NewEnvDescriber(describe.NewEnvDescriberConfig{
-					App:         app,
-					Env:         env,
-					ConfigStore: store,
-				})
-				if err != nil {
-					return nil, fmt.Errorf("new env describer for environment %s in app %s: %v", env, app, err)
-				}
-				return d, nil
-			},
+			sessProvider:     sessProvider,
+			newTplGenerator:  newWkldTplGenerator,
 		}
 	}
 	return opts, nil
@@ -215,5 +194,6 @@ func buildJobPackageCmd() *cobra.Command {
 	cmd.Flags().StringVarP(&vars.appName, appFlag, appFlagShort, tryReadingAppName(), appFlagDescription)
 	cmd.Flags().StringVar(&vars.tag, imageTagFlag, "", imageTagFlagDescription)
 	cmd.Flags().StringVar(&vars.outputDir, stackOutputDirFlag, "", stackOutputDirFlagDescription)
+	cmd.Flags().BoolVar(&vars.uploadAssets, uploadAssetsFlag, false, uploadAssetsFlagDescription)
 	return cmd
 }
