@@ -27,21 +27,21 @@ type Environment struct {
 	Telemetry        *Telemetry    `json:"telemetry,omitempty"`    // Optional environment telemetry features.
 }
 
-// CustomizeEnv represents the custom environment config.
-type CustomizeEnv struct {
-	ImportVPC *ImportVPC `json:"importVPC,omitempty"`
-	VPCConfig *AdjustVPC `json:"adjustVPC,omitempty"`
+// HasImportedCerts return if the environment has imported certs.
+func (e *Environment) HasImportedCerts() bool {
+	return e.CustomConfig != nil && len(e.CustomConfig.ImportCertARNs) != 0
 }
 
-// NewCustomizeEnv returns a new CustomizeEnv struct.
-func NewCustomizeEnv(importVPC *ImportVPC, adjustVPC *AdjustVPC) *CustomizeEnv {
-	if importVPC == nil && adjustVPC == nil {
-		return nil
-	}
-	return &CustomizeEnv{
-		ImportVPC: importVPC,
-		VPCConfig: adjustVPC,
-	}
+// CustomizeEnv represents the custom environment config.
+type CustomizeEnv struct {
+	ImportVPC      *ImportVPC `json:"importVPC,omitempty"`
+	VPCConfig      *AdjustVPC `json:"adjustVPC,omitempty"`
+	ImportCertARNs []string   `json:"importCertARNs,omitempty"`
+}
+
+// IsEmpty returns if CustomizeEnv is an empty struct.
+func (c CustomizeEnv) IsEmpty() bool {
+	return c.ImportVPC == nil && c.VPCConfig == nil && len(c.ImportCertARNs) == 0
 }
 
 // ImportVPC holds the fields to import VPC resources.
@@ -77,7 +77,7 @@ func (s *Store) CreateEnvironment(environment *Environment) error {
 		return fmt.Errorf("serializing environment %s: %w", environment.Name, err)
 	}
 
-	_, err = s.ssmClient.PutParameter(&ssm.PutParameterInput{
+	_, err = s.ssm.PutParameter(&ssm.PutParameterInput{
 		Name:        aws.String(environmentPath),
 		Description: aws.String(fmt.Sprintf("The %s deployment stage", environment.Name)),
 		Type:        aws.String(ssm.ParameterTypeString),
@@ -99,7 +99,7 @@ func (s *Store) CreateEnvironment(environment *Environment) error {
 // it returns ErrNoSuchEnvironment.
 func (s *Store) GetEnvironment(appName string, environmentName string) (*Environment, error) {
 	environmentPath := fmt.Sprintf(fmtEnvParamPath, appName, environmentName)
-	environmentParam, err := s.ssmClient.GetParameter(&ssm.GetParameterInput{
+	environmentParam, err := s.ssm.GetParameter(&ssm.GetParameterInput{
 		Name: aws.String(environmentPath),
 	})
 
@@ -151,7 +151,7 @@ func (s *Store) ListEnvironments(appName string) ([]*Environment, error) {
 // If the environment does not exist in the store or is successfully deleted then returns nil. Otherwise, returns an error.
 func (s *Store) DeleteEnvironment(appName, environmentName string) error {
 	paramName := fmt.Sprintf(fmtEnvParamPath, appName, environmentName)
-	_, err := s.ssmClient.DeleteParameter(&ssm.DeleteParameterInput{
+	_, err := s.ssm.DeleteParameter(&ssm.DeleteParameterInput{
 		Name: aws.String(paramName),
 	})
 
