@@ -232,6 +232,10 @@ Outputs:
 						AssignPublicIP: template.EnablePublicIP,
 						SubnetsType:    template.PublicSubnetsPlacement,
 					},
+					DeploymentConfiguration: template.DeploymentConfigurationOpts{
+						MinHealthyPercent: 100,
+						MaxPercent:        200,
+					},
 					EntryPoint: []string{"/bin/echo", "hello"},
 					Command:    []string{"world"},
 					ALBEnabled: true,
@@ -272,6 +276,10 @@ Outputs:
 						AssignPublicIP: template.EnablePublicIP,
 						SubnetsType:    template.PublicSubnetsPlacement,
 					},
+					DeploymentConfiguration: template.DeploymentConfigurationOpts{
+						MinHealthyPercent: 100,
+						MaxPercent:        200,
+					},
 					EntryPoint: []string{"/bin/echo", "hello"},
 					Command:    []string{"world"},
 					ALBEnabled: true,
@@ -451,7 +459,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
-					ParameterValue: aws.String("true"),
+					ParameterValue: aws.String("false"),
 				},
 			}...),
 		},
@@ -536,7 +544,7 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 				},
 				{
 					ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
-					ParameterValue: aws.String("true"),
+					ParameterValue: aws.String("false"),
 				},
 			}...),
 		},
