@@ -1,3 +1,4 @@
+//go:build integration || localintegration
 // +build integration localintegration
 
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
@@ -39,7 +40,7 @@ func TestScheduledJob_Template(t *testing.T) {
 	envMft, err := mft.ApplyEnv(envName)
 	require.NoError(t, err)
 
-	err = mft.Validate()
+	err = envMft.Validate()
 	require.NoError(t, err)
 
 	v, ok := envMft.(*manifest.ScheduledJob)
