@@ -25,7 +25,6 @@ const (
 
 	taskContainerImageParamKey = "ContainerImage"
 	taskTaskRoleParamKey       = "TaskRole"
-	taskExecutionRoleParamKey  = "ExecutionRole"
 	taskCommandParamKey        = "Command"
 	taskEntryPointParamKey     = "EntryPoint"
 	taskOSParamKey             = "OS"
@@ -53,15 +52,28 @@ func (t *taskStackConfig) StackName() string {
 	return string(NameForTask(t.Name))
 }
 
+var cfnFuntion = map[string]interface{}{
+	"isARN":           template.IsARNFunc,
+	"trimSlashPrefix": template.TrimSlashPrefix,
+}
+
 // Template returns the task CloudFormation template.
 func (t *taskStackConfig) Template() (string, error) {
 	content, err := t.parser.Parse(taskTemplatePath, struct {
-		EnvVars map[string]string
-		Secrets map[string]string
+		EnvVars               map[string]string
+		SSMParamSecrets       map[string]string
+		SecretsManagerSecrets map[string]string
+		App                   string
+		Env                   string
+		ExecutionRole         string
 	}{
-		EnvVars: t.EnvVars,
-		Secrets: t.Secrets,
-	})
+		EnvVars:               t.EnvVars,
+		SSMParamSecrets:       t.SSMParamSecrets,
+		SecretsManagerSecrets: t.SecretsManagerSecrets,
+		App:                   t.App,
+		Env:                   t.Env,
+		ExecutionRole:         t.ExecutionRole,
+	}, template.WithFuncs(cfnFuntion))
 	if err != nil {
 		return "", fmt.Errorf("read template for task stack: %w", err)
 	}
@@ -95,10 +107,6 @@ func (t *taskStackConfig) Parameters() ([]*cloudformation.Parameter, error) {
 			ParameterKey:   aws.String(taskTaskRoleParamKey),
 			ParameterValue: aws.String(t.TaskRole),
 		},
-		{
-			ParameterKey:   aws.String(taskExecutionRoleParamKey),
-			ParameterValue: aws.String(t.ExecutionRole),
-		},
 		{
 			ParameterKey:   aws.String(taskCommandParamKey),
 			ParameterValue: aws.String(strings.Join(t.Command, ",")),
@@ -118,6 +126,13 @@ func (t *taskStackConfig) Parameters() ([]*cloudformation.Parameter, error) {
 	}, nil
 }
 
+// SerializedParameters returns the CloudFormation stack's parameters serialized
+// to a YAML document annotated with comments for readability to users.
+func (s *taskStackConfig) SerializedParameters() (string, error) {
+	// No-op for now.
+	return "", nil
+}
+
 // Tags returns the tags that should be applied to the task CloudFormation.
 func (t *taskStackConfig) Tags() []*cloudformation.Tag {
 	tags := map[string]string{
