@@ -7,11 +7,13 @@ package deploy
 import (
 	"fmt"
 	"sort"
-
+	
+	"github.com/aws/aws-sdk-go/aws/arn"
+	"github.com/aws/aws-sdk-go/aws/session"
+	
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
-
+	
 	rg "github.com/aws/copilot-cli/internal/pkg/aws/resourcegroups"
-	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 )
 
@@ -20,22 +22,26 @@ const (
 	AppTagKey = "copilot-application"
 	// EnvTagKey is tag key for Copilot env.
 	EnvTagKey = "copilot-environment"
-	// ServiceTagKey is tag key for Copilot svc.
+	// ServiceTagKey is tag key for Copilot service.
 	ServiceTagKey = "copilot-service"
+	// PipelineTagKey is tag key for Copilot pipeline.
+	PipelineTagKey = "copilot-pipeline"
 	// TaskTagKey is tag key for Copilot task.
 	TaskTagKey = "copilot-task"
 )
 
 const (
-	stackResourceType = "cloudformation:stack"
-	snsResourceType   = "sns"
+	stackResourceType    = "cloudformation:stack"
+	pipelineResourceType = "codepipeline:pipeline"
+	snsResourceType      = "sns"
 
 	// fmtSNSTopicNamePrefix holds the App-Env-Workload- components of a topic name
 	fmtSNSTopicNamePrefix = "%s-%s-%s-"
 	snsServiceName        = "sns"
 )
 
-type resourceGetter interface {
+// ResourceGetter retrieves a group of resources that satisfy certain conditions, such as tags.
+type ResourceGetter interface {
 	GetResourcesByTags(resourceType string, tags map[string]string) ([]*rg.Resource, error)
 }
 
@@ -48,31 +54,36 @@ type ConfigStoreClient interface {
 	GetJob(appName, jobname string) (*config.Workload, error)
 }
 
+// SessionProvider is the interface to provide configuration for the AWS SDK's service clients.
+type SessionProvider interface {
+	FromRole(roleARN, region string) (*session.Session, error)
+}
+
 // Store fetches information on deployed services.
 type Store struct {
 	configStore         ConfigStoreClient
-	newRgClientFromIDs  func(string, string) (resourceGetter, error)
-	newRgClientFromRole func(string, string) (resourceGetter, error)
+	newRgClientFromIDs  func(string, string) (ResourceGetter, error)
+	newRgClientFromRole func(string, string) (ResourceGetter, error)
 }
 
 // NewStore returns a new store.
-func NewStore(store ConfigStoreClient) (*Store, error) {
+func NewStore(sessProvider SessionProvider, store ConfigStoreClient) (*Store, error) {
 	s := &Store{
 		configStore: store,
 	}
-	s.newRgClientFromIDs = func(appName, envName string) (resourceGetter, error) {
+	s.newRgClientFromIDs = func(appName, envName string) (ResourceGetter, error) {
 		env, err := s.configStore.GetEnvironment(appName, envName)
 		if err != nil {
 			return nil, fmt.Errorf("get environment config %s: %w", envName, err)
 		}
-		sess, err := sessions.NewProvider().FromRole(env.ManagerRoleARN, env.Region)
+		sess, err := sessProvider.FromRole(env.ManagerRoleARN, env.Region)
 		if err != nil {
 			return nil, fmt.Errorf("create new session from env role: %w", err)
 		}
 		return rg.New(sess), nil
 	}
-	s.newRgClientFromRole = func(roleARN, region string) (resourceGetter, error) {
-		sess, err := sessions.NewProvider().FromRole(roleARN, region)
+	s.newRgClientFromRole = func(roleARN, region string) (ResourceGetter, error) {
+		sess, err := sessProvider.FromRole(roleARN, region)
 		if err != nil {
 			return nil, fmt.Errorf("create new session from env role: %w", err)
 		}
@@ -81,6 +92,60 @@ func NewStore(store ConfigStoreClient) (*Store, error) {
 	return s, nil
 }
 
+// Pipeline is a deployed pipeline.
+type Pipeline struct {
+	// The name of the application that the pipeline is associated with.
+	AppName string
+	// The pipeline resource name (physical resource ID) generated by CloudFormation.
+	ResourceName string
+	// The name given by user in the pipeline manifest.
+	Name string
+	// Whether the pipeline follows legacy-naming, i.e. not namespaced with "pipeline-app-".
+	IsLegacy bool
+}
+
+// PipelineStore fetches information on deployed pipelines.
+type PipelineStore struct {
+	getter ResourceGetter
+}
+
+// NewPipelineStore returns a new PipelineStore.
+func NewPipelineStore(getter ResourceGetter) *PipelineStore {
+	return &PipelineStore{
+		getter: getter,
+	}
+}
+
+// ListDeployedPipelines returns a list of names of deployed pipelines by looking up
+// pipeline resources with tags.
+func (p *PipelineStore) ListDeployedPipelines(appName string) ([]Pipeline, error) {
+	var pipelines []Pipeline
+	pipelineResources, err := p.getter.GetResourcesByTags(pipelineResourceType, map[string]string{
+		AppTagKey: appName,
+	})
+	if err != nil {
+		return nil, fmt.Errorf("get pipeline resources by tags for app %s: %w", appName, err)
+	}
+	for _, pipelineRes := range pipelineResources {
+		resourceName, err := getPipelineResourceName(pipelineRes.ARN)
+		if err != nil {
+			return nil, err
+		}
+		pipeline := Pipeline{
+			ResourceName: resourceName,
+			AppName:      appName,
+		}
+		if name, ok := pipelineRes.Tags[PipelineTagKey]; !ok {
+			pipeline.IsLegacy = true
+			pipeline.Name = resourceName // A legacy-named pipeline's resource name is the same as pipeline name.
+		} else {
+			pipeline.Name = name
+		}
+		pipelines = append(pipelines, pipeline)
+	}
+	return pipelines, nil
+}
+
 // ListDeployedServices returns the names of deployed services in an environment.
 func (s *Store) ListDeployedServices(appName string, envName string) ([]string, error) {
 	return s.listDeployedWorkloads(appName, envName, manifest.ServiceTypes())
@@ -189,7 +254,7 @@ type result struct {
 	err  error
 }
 
-func (s *Store) deployedServices(rgClient resourceGetter, app, env, svc string) result {
+func (s *Store) deployedServices(rgClient ResourceGetter, app, env, svc string) result {
 	resources, err := rgClient.GetResourcesByTags(stackResourceType, map[string]string{
 		AppTagKey:     app,
 		EnvTagKey:     env,
@@ -265,3 +330,12 @@ func (s *Store) isWorkloadDeployed(appName, envName, name string) (bool, error)
 	}
 	return false, nil
 }
+
+func getPipelineResourceName(resourceArn string) (string, error) {
+	parsedArn, err := arn.Parse(resourceArn)
+	if err != nil {
+		return "", fmt.Errorf("parse pipeline ARN: %s", resourceArn)
+	}
+
+	return parsedArn.Resource, nil
+}
