@@ -8,9 +8,16 @@ package deploy
 import (
 	"errors"
 	"fmt"
+	"path"
+	"path/filepath"
 	"regexp"
+	"sort"
 	"strings"
 
+	"github.com/aws/copilot-cli/internal/pkg/graph"
+
+	"github.com/aws/copilot-cli/internal/pkg/config"
+
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 
 	"github.com/aws/aws-sdk-go/aws/arn"
@@ -24,8 +31,10 @@ const (
 	fmtErrMissingProperty    = "missing `%s` in properties"
 	fmtErrPropertyNotAString = "property `%s` is not a string"
 
-	defaultPipelineBuildImage = "aws/codebuild/amazonlinux2-x86_64-standard:3.0"
+	defaultPipelineBuildImage      = "aws/codebuild/amazonlinux2-x86_64-standard:3.0"
 	defaultPipelineEnvironmentType = "LINUX_CONTAINER"
+
+	defaultPipelineArtifactsDir = "infrastructure"
 )
 
 var (
@@ -46,6 +55,9 @@ type CreatePipelineInput struct {
 	// Name of the pipeline
 	Name string
 
+	// IsLegacy should be set to true if the pipeline has been deployed using a legacy non-namespaced name; otherwise it is false.
+	IsLegacy bool
+
 	// The source code provider for this pipeline
 	Source interface{}
 
@@ -68,8 +80,28 @@ type CreatePipelineInput struct {
 // to build and test Docker image.
 type Build struct {
 	// The URI that identifies the Docker image to use for this build project.
-	Image string
+	Image           string
 	EnvironmentType string
+	BuildspecPath   string
+}
+
+// Init populates the fields in Build by parsing the manifest file's "build" section.
+func (b *Build) Init(mfBuild *manifest.Build, mfDirPath string) {
+	image := defaultPipelineBuildImage
+	environmentType := defaultPipelineEnvironmentType
+	path := filepath.Join(mfDirPath, "buildspec.yml")
+	if mfBuild != nil && mfBuild.Image != "" {
+		image = mfBuild.Image
+	}
+	if mfBuild != nil && mfBuild.Buildspec != "" {
+		path = mfBuild.Buildspec
+	}
+	if strings.Contains(image, "aarch64") {
+		environmentType = "ARM_CONTAINER"
+	}
+	b.Image = image
+	b.EnvironmentType = environmentType
+	b.BuildspecPath = filepath.ToSlash(path) // Buildspec path must be with '/' because CloudFormation expects forward-slash separated file path.
 }
 
 // ArtifactBucket represents an S3 bucket used by the CodePipeline to store
@@ -237,22 +269,6 @@ func PipelineSourceFromManifest(mfSource *manifest.Source) (source interface{},
 	}
 }
 
-// PipelineBuildFromManifest processes manifest info about the build project settings.
-func PipelineBuildFromManifest(mfBuild *manifest.Build) (build *Build) {
-	image := defaultPipelineBuildImage
-	environmentType := defaultPipelineEnvironmentType
-	if mfBuild != nil && mfBuild.Image != "" {
-		image = mfBuild.Image
-	}
-	if strings.Contains(image, "aarch64")  {
-		environmentType = "ARM_CONTAINER"
-	} 
-	return &Build{
-		Image: image,
-		EnvironmentType: environmentType,
-	}
-}
-
 // GitHubPersonalAccessTokenSecretID returns the ID of the secret in the
 // Secrets manager, which stores the GitHub Personal Access token if the
 // provider is "GitHubV1".
@@ -432,41 +448,265 @@ func (s *GitHubV1Source) Owner() (string, error) {
 	return owner, nil
 }
 
+type associatedEnvironment struct {
+	// Name of the environment, must be unique within an application.
+	// This is also the name of the pipeline stage.
+	Name string
+
+	// The region this environment is created in.
+	Region string
+
+	// AppName represents the application name the environment is part of.
+	AppName string
+
+	// AccountID of the account this environment is stored in.
+	AccountID string
+}
+
 // PipelineStage represents configuration for each deployment stage
 // of a workspace. A stage consists of the Config Environment the pipeline
 // is deploying to, the containerized services that will be deployed, and
 // test commands, if the user has opted to add any.
 type PipelineStage struct {
-	*AssociatedEnvironment
-	LocalWorkloads   []string
-	RequiresApproval bool
-	TestCommands     []string
+	*associatedEnvironment
+	requiresApproval  bool
+	testCommands      []string
+	execRoleARN       string
+	envManagerRoleARN string
+	deployments       manifest.Deployments
 }
 
-// WorkloadTemplatePath returns the full path to the workload CFN template
-// built during the build stage.
-func (s *PipelineStage) WorkloadTemplatePath(wlName string) string {
-	return fmt.Sprintf(WorkloadCfnTemplateNameFormat, wlName, s.Name)
+// Init populates the fields in PipelineStage against a target environment,
+// the user's manifest config, and any local workload names.
+func (stg *PipelineStage) Init(env *config.Environment, mftStage *manifest.PipelineStage, workloads []string) {
+	stg.associatedEnvironment = &associatedEnvironment{
+		AppName:   env.App,
+		Name:      mftStage.Name,
+		Region:    env.Region,
+		AccountID: env.AccountID,
+	}
+	deployments := mftStage.Deployments
+	if len(deployments) == 0 {
+		// Transform local workloads into the manifest.Deployments format if the manifest doesn't have any deployment config.
+		deployments = make(manifest.Deployments)
+		for _, workload := range workloads {
+			deployments[workload] = nil
+		}
+	}
+
+	stg.deployments = deployments
+	stg.requiresApproval = mftStage.RequiresApproval
+	stg.testCommands = mftStage.TestCommands
+	stg.execRoleARN = env.ExecutionRoleARN
+	stg.envManagerRoleARN = env.ManagerRoleARN
 }
 
-// WorkloadTemplateConfigurationPath returns the full path to the workload CFN
-// template configuration file built during the build stage.
-func (s *PipelineStage) WorkloadTemplateConfigurationPath(wlName string) string {
-	return fmt.Sprintf(WorkloadCfnTemplateConfigurationNameFormat,
-		wlName, s.Name,
-	)
+// Name returns the stage's name.
+func (stg *PipelineStage) Name() string {
+	return stg.associatedEnvironment.Name
 }
 
-// AssociatedEnvironment defines the necessary information a pipeline stage
-// needs for an Config Environment.
-type AssociatedEnvironment struct {
-	// Name of the environment, must be unique within an application.
-	// This is also the name of the pipeline stage.
-	Name string
-
-	// The region this environment is stored in.
-	Region string
-
-	// AccountID of the account this environment is stored in.
-	AccountID string
+// Approval returns a manual approval action for the stage.
+// If the stage does not require approval, then returns nil.
+func (stg *PipelineStage) Approval() *ManualApprovalAction {
+	if !stg.requiresApproval {
+		return nil
+	}
+	return &ManualApprovalAction{
+		name: stg.associatedEnvironment.Name,
+	}
+}
+
+// Region returns the AWS region name, such as "us-west-2", where the deployments will occur.
+func (stg *PipelineStage) Region() string {
+	return stg.associatedEnvironment.Region
+}
+
+// ExecRoleARN returns the IAM role assumed by CloudFormation to create or update resources defined in a template.
+func (stg *PipelineStage) ExecRoleARN() string {
+	return stg.execRoleARN
+}
+
+// EnvManagerRoleARN returns the IAM role used to create or update CloudFormation stacks in an environment.
+func (stg *PipelineStage) EnvManagerRoleARN() string {
+	return stg.envManagerRoleARN
+}
+
+// Test returns a test for the stage.
+// If the stage does not have any test commands, then returns nil.
+func (stg *PipelineStage) Test() (*TestCommandsAction, error) {
+	if len(stg.testCommands) == 0 {
+		return nil, nil
+	}
+
+	var prevActions []orderedRunner
+	deployActions, err := stg.Deployments()
+	if err != nil {
+		return nil, err
+	}
+	for i := range deployActions {
+		prevActions = append(prevActions, &deployActions[i])
+	}
+
+	return &TestCommandsAction{
+		action: action{
+			prevActions: prevActions,
+		},
+		commands: stg.testCommands,
+	}, nil
+}
+
+// Deployments returns a list of deploy actions for the pipeline.
+func (stg *PipelineStage) Deployments() ([]DeployAction, error) {
+	var prevActions []orderedRunner
+	if approval := stg.Approval(); approval != nil {
+		prevActions = append(prevActions, approval)
+	}
+
+	topo, err := graph.TopologicalOrder(stg.buildDeploymentsGraph())
+	if err != nil {
+		return nil, fmt.Errorf("find an ordering for deployments: %v", err)
+	}
+
+	var actions []DeployAction
+	for name, conf := range stg.deployments {
+		actions = append(actions, DeployAction{
+			action: action{
+				prevActions: prevActions,
+			},
+			name:     name,
+			envName:  stg.associatedEnvironment.Name,
+			appName:  stg.AppName,
+			override: conf,
+			ranker:   topo,
+		})
+	}
+
+	sort.Slice(actions, func(i, j int) bool {
+		return actions[i].Name() < actions[j].Name()
+	})
+	return actions, nil
+}
+
+func (stg *PipelineStage) buildDeploymentsGraph() *graph.Graph[string] {
+	var names []string
+	for name, _ := range stg.deployments {
+		names = append(names, name)
+	}
+	digraph := graph.New(names...)
+	for name, conf := range stg.deployments {
+		if conf == nil {
+			continue
+		}
+		for _, dependency := range conf.DependsOn {
+			digraph.Add(graph.Edge[string]{
+				From: dependency, // Dependency must be completed before name.
+				To:   name,
+			})
+		}
+	}
+	return digraph
+}
+
+type orderedRunner interface {
+	RunOrder() int
+}
+
+// action represents a generic CodePipeline action.
+type action struct {
+	prevActions []orderedRunner // The last actions to be executed immediately before this action.
+}
+
+// RunOrder returns the order in which the action should run. A higher numbers means the action is run later.
+// Actions with the same RunOrder run in parallel.
+func (a *action) RunOrder() int {
+	max := 0
+	for _, prevAction := range a.prevActions {
+		if cur := prevAction.RunOrder(); cur > max {
+			max = cur
+		}
+	}
+	return max + 1
+}
+
+// ManualApprovalAction represents a stage approval action.
+type ManualApprovalAction struct {
+	action
+	name string // Name of the stage to approve.
+}
+
+// Name returns the name of the CodePipeline approval action for the stage.
+func (a *ManualApprovalAction) Name() string {
+	return fmt.Sprintf("ApprovePromotionTo-%s", a.name)
+}
+
+type ranker interface {
+	Rank(name string) (int, bool)
+}
+
+// DeployAction represents a CodePipeline action of category "Deploy" for a cloudformation stack.
+type DeployAction struct {
+	action
+
+	name     string
+	envName  string
+	appName  string
+	override *manifest.Deployment // User defined settings over Copilot's defaults.
+
+	ranker ranker // Interface to rank this deployment action against others in the same stage.
+}
+
+// Name returns the name of the CodePipeline deploy action for a workload.
+func (a *DeployAction) Name() string {
+	return fmt.Sprintf("CreateOrUpdate-%s-%s", a.name, a.envName)
+}
+
+// StackName returns the name of the workload stack to create or update.
+func (a *DeployAction) StackName() string {
+	if a.override != nil && a.override.StackName != "" {
+		return a.override.StackName
+	}
+	return fmt.Sprintf("%s-%s-%s", a.appName, a.envName, a.name)
+}
+
+// TemplatePath returns the path of the CloudFormation template file generated during the build phase.
+func (a *DeployAction) TemplatePath() string {
+	if a.override != nil && a.override.TemplatePath != "" {
+		return a.override.TemplatePath
+	}
+
+	// Use path.Join instead of filepath to join with "/" instead of OS-specific file separators.
+	return path.Join(defaultPipelineArtifactsDir, fmt.Sprintf(WorkloadCfnTemplateNameFormat, a.name, a.envName))
+}
+
+// TemplateConfigPath returns the path of the CloudFormation template config file generated during the build phase.
+func (a *DeployAction) TemplateConfigPath() string {
+	if a.override != nil && a.override.TemplateConfig != "" {
+		return a.override.TemplateConfig
+	}
+
+	// Use path.Join instead of filepath to join with "/" instead of OS-specific file separators.
+	return path.Join(defaultPipelineArtifactsDir, fmt.Sprintf(WorkloadCfnTemplateConfigurationNameFormat, a.name, a.envName))
+}
+
+// RunOrder returns the order in which the action should run.
+func (a *DeployAction) RunOrder() int {
+	rank, _ := a.ranker.Rank(a.name) // The deployment is guaranteed to be in the ranker.
+	return a.action.RunOrder() /* baseline */ + rank
+}
+
+// TestCommandsAction represents a CodePipeline action of category "Test" to validate deployments.
+type TestCommandsAction struct {
+	action
+	commands []string
+}
+
+// Name returns the name of the test action.
+func (a *TestCommandsAction) Name() string {
+	return "TestCommands"
+}
+
+// Commands returns the list commands to run part of the test action.
+func (a *TestCommandsAction) Commands() []string {
+	return a.commands
 }
