@@ -63,6 +63,16 @@ func TestEnvDescriber_Describe(t *testing.T) {
 		Name: "testSvc3",
 		Type: "load-balanced",
 	}
+	testJob1 := &config.Workload{
+		App:  "testApp",
+		Name: "testJob1",
+		Type: "Scheduled Job",
+	}
+	testJob2 := &config.Workload{
+		App:  "testApp",
+		Name: "testJob2",
+		Type: "Scheduled Job",
+	}
 	stackTags := map[string]string{
 		"copilot-application": "testApp",
 		"copilot-environment": "testEnv",
@@ -81,6 +91,7 @@ func TestEnvDescriber_Describe(t *testing.T) {
 		Type:       "testApp-testEnv-Cluster",
 	}
 	envSvcs := []*config.Workload{testSvc1, testSvc2}
+	envJobs := []*config.Workload{testJob1, testJob2}
 	mockError := errors.New("some error")
 	testCases := map[string]struct {
 		shouldOutputResources bool
@@ -119,6 +130,11 @@ func TestEnvDescriber_Describe(t *testing.T) {
 					}, nil),
 					m.deployStoreSvc.EXPECT().ListDeployedServices(testApp, testEnv.Name).
 						Return([]string{"testSvc1", "testSvc2"}, nil),
+					m.configStoreSvc.EXPECT().ListJobs(testApp).Return([]*config.Workload{
+						testJob1, testJob2,
+					}, nil),
+					m.deployStoreSvc.EXPECT().ListDeployedJobs(testApp, testEnv.Name).
+						Return([]string{"testJob1", "testJob2"}, nil),
 					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{}, mockError),
 				)
 			},
@@ -133,6 +149,11 @@ func TestEnvDescriber_Describe(t *testing.T) {
 					}, nil),
 					m.deployStoreSvc.EXPECT().ListDeployedServices(testApp, testEnv.Name).
 						Return([]string{"testSvc1", "testSvc2"}, nil),
+					m.configStoreSvc.EXPECT().ListJobs(testApp).Return([]*config.Workload{
+						testJob1, testJob2,
+					}, nil),
+					m.deployStoreSvc.EXPECT().ListDeployedJobs(testApp, testEnv.Name).
+						Return([]string{"testJob1", "testJob2"}, nil),
 					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{
 						Tags:    stackTags,
 						Outputs: stackOutputs,
@@ -151,6 +172,11 @@ func TestEnvDescriber_Describe(t *testing.T) {
 					}, nil),
 					m.deployStoreSvc.EXPECT().ListDeployedServices(testApp, testEnv.Name).
 						Return([]string{"testSvc1", "testSvc2"}, nil),
+					m.configStoreSvc.EXPECT().ListJobs(testApp).Return([]*config.Workload{
+						testJob1, testJob2,
+					}, nil),
+					m.deployStoreSvc.EXPECT().ListDeployedJobs(testApp, testEnv.Name).
+						Return([]string{"testJob1", "testJob2"}, nil),
 					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{
 						Tags:    stackTags,
 						Outputs: stackOutputs,
@@ -160,6 +186,7 @@ func TestEnvDescriber_Describe(t *testing.T) {
 			wantedEnv: &EnvDescription{
 				Environment: testEnv,
 				Services:    envSvcs,
+				Jobs:        envJobs,
 				Tags:        map[string]string{"copilot-application": "testApp", "copilot-environment": "testEnv"},
 				EnvironmentVPC: EnvironmentVPC{
 					ID:               "vpc-012abcd345",
@@ -177,6 +204,11 @@ func TestEnvDescriber_Describe(t *testing.T) {
 					}, nil),
 					m.deployStoreSvc.EXPECT().ListDeployedServices(testApp, testEnv.Name).
 						Return([]string{"testSvc1", "testSvc2"}, nil),
+					m.configStoreSvc.EXPECT().ListJobs(testApp).Return([]*config.Workload{
+						testJob1, testJob2,
+					}, nil),
+					m.deployStoreSvc.EXPECT().ListDeployedJobs(testApp, testEnv.Name).
+						Return([]string{"testJob1", "testJob2"}, nil),
 					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{
 						Tags:    stackTags,
 						Outputs: stackOutputs,
@@ -190,6 +222,7 @@ func TestEnvDescriber_Describe(t *testing.T) {
 			wantedEnv: &EnvDescription{
 				Environment: testEnv,
 				Services:    envSvcs,
+				Jobs:        envJobs,
 				Tags:        map[string]string{"copilot-application": "testApp", "copilot-environment": "testEnv"},
 				Resources:   wantedResources,
 				EnvironmentVPC: EnvironmentVPC{
@@ -487,8 +520,14 @@ func TestEnvDescription_JSONString(t *testing.T) {
 		Name: "testSvc3",
 		Type: "load-balanced",
 	}
+	testJob1 := &config.Workload{
+		App:  "testApp",
+		Name: "testJob1",
+		Type: "Scheduled Job",
+	}
 	allSvcs := []*config.Workload{testSvc1, testSvc2, testSvc3}
-	wantedContent := "{\"environment\":{\"app\":\"testApp\",\"name\":\"testEnv\",\"region\":\"us-west-2\",\"accountID\":\"123456789012\",\"prod\":false,\"registryURL\":\"\",\"executionRoleARN\":\"\",\"managerRoleARN\":\"\",\"customConfig\":{}},\"services\":[{\"app\":\"testApp\",\"name\":\"testSvc1\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc2\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc3\",\"type\":\"load-balanced\"}],\"tags\":{\"key1\":\"value1\",\"key2\":\"value2\"},\"resources\":[{\"type\":\"AWS::IAM::Role\",\"physicalID\":\"testApp-testEnv-CFNExecutionRole\"},{\"type\":\"testApp-testEnv-Cluster\",\"physicalID\":\"AWS::ECS::Cluster-jI63pYBWU6BZ\"}],\"environmentVPC\":{\"id\":\"\",\"publicSubnetIDs\":null,\"privateSubnetIDs\":null}}\n"
+	allJobs := []*config.Workload{testJob1}
+	wantedContent := "{\"environment\":{\"app\":\"testApp\",\"name\":\"testEnv\",\"region\":\"us-west-2\",\"accountID\":\"123456789012\",\"prod\":false,\"registryURL\":\"\",\"executionRoleARN\":\"\",\"managerRoleARN\":\"\",\"customConfig\":{}},\"services\":[{\"app\":\"testApp\",\"name\":\"testSvc1\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc2\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc3\",\"type\":\"load-balanced\"}],\"jobs\":[{\"app\":\"testApp\",\"name\":\"testJob1\",\"type\":\"Scheduled Job\"}],\"tags\":{\"key1\":\"value1\",\"key2\":\"value2\"},\"resources\":[{\"type\":\"AWS::IAM::Role\",\"physicalID\":\"testApp-testEnv-CFNExecutionRole\"},{\"type\":\"testApp-testEnv-Cluster\",\"physicalID\":\"AWS::ECS::Cluster-jI63pYBWU6BZ\"}],\"environmentVPC\":{\"id\":\"\",\"publicSubnetIDs\":null,\"privateSubnetIDs\":null}}\n"
 
 	// GIVEN
 	ctrl := gomock.NewController(t)
@@ -498,6 +537,7 @@ func TestEnvDescription_JSONString(t *testing.T) {
 		Environment:    testEnv,
 		EnvironmentVPC: EnvironmentVPC{},
 		Services:       allSvcs,
+		Jobs:           allJobs,
 		Tags:           testApp.Tags,
 		Resources:      wantedResources,
 	}
@@ -539,7 +579,13 @@ func TestEnvDescription_HumanString(t *testing.T) {
 		Name: "testSvc3",
 		Type: "load-balanced",
 	}
+	testJob1 := &config.Workload{
+		App:  "testApp",
+		Name: "testJob1",
+		Type: "Scheduled Job",
+	}
 	allSvcs := []*config.Workload{testSvc1, testSvc2, testSvc3}
+	allJobs := []*config.Workload{testJob1}
 
 	wantedContent := `About
 
@@ -548,13 +594,14 @@ func TestEnvDescription_HumanString(t *testing.T) {
   Region      us-west-2
   Account ID  123456789012
 
-Services
+Workloads
 
   Name      Type
   ----      ----
   testSvc1  load-balanced
   testSvc2  load-balanced
   testSvc3  load-balanced
+  testJob1  Scheduled Job
 
 Tags
 
@@ -575,6 +622,7 @@ Resources
 	d := &EnvDescription{
 		Environment: testEnv,
 		Services:    allSvcs,
+		Jobs:        allJobs,
 		Tags:        testApp.Tags,
 		Resources:   wantedResources,
 	}
