@@ -10,6 +10,7 @@ import (
 
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/describe/mocks"
+
 	describeStack "github.com/aws/copilot-cli/internal/pkg/describe/stack"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
@@ -41,7 +42,7 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("get stack resources for service jobs: some error"),
 		},
-		"fail to get parameters of environment stack when fetching ALB uris": {
+		"fail to get params of the service stack when fetching ALB uris": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
 				gomock.InOrder(
 					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
@@ -49,10 +50,10 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(nil, mockErr),
+					m.ecsDescriber.EXPECT().Params().Return(nil, mockErr),
 				)
 			},
-			wantedError: fmt.Errorf("get stack parameters for environment test: some error"),
+			wantedError: fmt.Errorf("get stack parameters for service jobs: some error"),
 		},
 		"fail to get outputs of environment stack when fetching ALB uris": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
@@ -62,13 +63,15 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{}, nil),
+					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
+						stack.LBWebServiceRulePathParamKey: testSvcPath,
+					}, nil),
 					m.envDescriber.EXPECT().Outputs().Return(nil, mockErr),
 				)
 			},
 			wantedError: fmt.Errorf("get stack outputs for environment test: some error"),
 		},
-		"fail to get parameters of service stack when fetching ALB uris": {
+		"fail to get listener rule host-header": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
 				gomock.InOrder(
 					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
@@ -76,15 +79,23 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{}, nil),
-					m.envDescriber.EXPECT().Outputs().Return(map[string]string{
-						envOutputPublicLoadBalancerDNSName: testEnvLBDNSName,
-						envOutputSubdomain:                 testEnvSubdomain,
+					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
+						stack.LBWebServiceRulePathParamKey: testSvcPath,
+						stack.LBWebServiceHTTPSParamKey:    "true",
 					}, nil),
-					m.ecsDescriber.EXPECT().Params().Return(nil, mockErr),
+					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
+						{
+							LogicalID:  svcStackResourceHTTPSListenerRuleLogicalID,
+							Type:       svcStackResourceHTTPSListenerRuleResourceType,
+							PhysicalID: "mockRuleARN",
+						},
+					}, nil),
+					m.lbDescriber.EXPECT().ListenerRuleHostHeaders("mockRuleARN").
+						Return(nil, mockErr),
 				)
 			},
-			wantedError: fmt.Errorf("get stack parameters for service jobs: some error"),
+
+			wantedError: fmt.Errorf("get host headers for listener rule mockRuleARN: some error"),
 		},
 		"https web service": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
@@ -94,19 +105,23 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{}, nil),
-					m.envDescriber.EXPECT().Outputs().Return(map[string]string{
-						envOutputPublicLoadBalancerDNSName: testEnvLBDNSName,
-						envOutputSubdomain:                 testEnvSubdomain,
-					}, nil),
 					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
 						stack.LBWebServiceRulePathParamKey: testSvcPath,
 						stack.LBWebServiceHTTPSParamKey:    "true",
 					}, nil),
+					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
+						{
+							LogicalID:  svcStackResourceHTTPSListenerRuleLogicalID,
+							Type:       svcStackResourceHTTPSListenerRuleResourceType,
+							PhysicalID: "mockRuleARN",
+						},
+					}, nil),
+					m.lbDescriber.EXPECT().ListenerRuleHostHeaders("mockRuleARN").
+						Return([]string{"jobs.test.phonetool.com", "phonetool.com"}, nil),
 				)
 			},
 
-			wantedURI: "https://jobs.test.phonetool.com",
+			wantedURI: "https://jobs.test.phonetool.com or https://phonetool.com",
 		},
 		"http web service": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
@@ -116,41 +131,16 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{}, nil),
+					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
+						stack.LBWebServiceRulePathParamKey: "mySvc",
+					}, nil),
 					m.envDescriber.EXPECT().Outputs().Return(map[string]string{
 						envOutputPublicLoadBalancerDNSName: testEnvLBDNSName,
 					}, nil),
-					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
-						stack.LBWebServiceRulePathParamKey: "*",
-					}, nil),
 				)
 			},
 
-			wantedURI: "http://abc.us-west-1.elb.amazonaws.com/*",
-		},
-		"with alias": {
-			setupMocks: func(m lbWebSvcDescriberMocks) {
-				gomock.InOrder(
-					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
-						{
-							LogicalID: svcStackResourceALBTargetGroupLogicalID,
-						},
-					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{
-						stack.EnvParamAliasesKey: `{"jobs": ["example.com", "v1.example.com"]}`,
-					}, nil),
-					m.envDescriber.EXPECT().Outputs().Return(map[string]string{
-						envOutputPublicLoadBalancerDNSName: testEnvLBDNSName,
-						envOutputSubdomain:                 testEnvSubdomain,
-					}, nil),
-					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
-						stack.LBWebServiceRulePathParamKey: testSvcPath,
-						stack.LBWebServiceHTTPSParamKey:    "true",
-					}, nil),
-				)
-			},
-
-			wantedURI: "https://example.com or https://v1.example.com",
+			wantedURI: "http://abc.us-west-1.elb.amazonaws.com/mySvc",
 		},
 		"fail to get parameters of service stack when fetching NLB uris": {
 			setupMocks: func(m lbWebSvcDescriberMocks) {
@@ -259,17 +249,19 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 							LogicalID: svcStackResourceALBTargetGroupLogicalID,
 						},
 					}, nil),
-					m.envDescriber.EXPECT().Params().Return(map[string]string{
-						stack.EnvParamAliasesKey: `{"jobs": ["example.com", "v1.example.com"]}`,
-					}, nil),
-					m.envDescriber.EXPECT().Outputs().Return(map[string]string{
-						envOutputPublicLoadBalancerDNSName: testEnvLBDNSName,
-						envOutputSubdomain:                 testEnvSubdomain,
-					}, nil),
 					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
 						stack.LBWebServiceRulePathParamKey: testSvcPath,
 						stack.LBWebServiceHTTPSParamKey:    "true",
 					}, nil),
+					m.ecsDescriber.EXPECT().ServiceStackResources().Return([]*describeStack.Resource{
+						{
+							LogicalID:  svcStackResourceHTTPSListenerRuleLogicalID,
+							Type:       svcStackResourceHTTPSListenerRuleResourceType,
+							PhysicalID: "mockRuleARN",
+						},
+					}, nil),
+					m.lbDescriber.EXPECT().ListenerRuleHostHeaders("mockRuleARN").
+						Return([]string{"example.com", "v1.example.com"}, nil),
 					m.ecsDescriber.EXPECT().Params().Return(map[string]string{
 						stack.LBWebServiceNLBPortParamKey:      "443",
 						stack.LBWebServiceDNSDelegatedParamKey: "true",
@@ -289,24 +281,21 @@ func TestLBWebServiceDescriber_URI(t *testing.T) {
 
 			mockSvcDescriber := mocks.NewMockecsDescriber(ctrl)
 			mockEnvDescriber := mocks.NewMockenvDescriber(ctrl)
+			mockLBDescriber := mocks.NewMocklbDescriber(ctrl)
 			mocks := lbWebSvcDescriberMocks{
 				ecsDescriber: mockSvcDescriber,
 				envDescriber: mockEnvDescriber,
+				lbDescriber:  mockLBDescriber,
 			}
 
 			tc.setupMocks(mocks)
 
 			d := &LBWebServiceDescriber{
-				app:         testApp,
-				svc:         testSvc,
-				initClients: func(string) error { return nil },
-
-				ecsServiceDescribers: map[string]ecsDescriber{
-					"test": mockSvcDescriber,
-				},
-				envDescriber: map[string]envDescriber{
-					"test": mockEnvDescriber,
-				},
+				app:                      testApp,
+				svc:                      testSvc,
+				initECSServiceDescribers: func(s string) (ecsDescriber, error) { return mockSvcDescriber, nil },
+				initEnvDescribers:        func(s string) (envDescriber, error) { return mockEnvDescriber, nil },
+				initLBDescriber:          func(s string) (lbDescriber, error) { return mockLBDescriber, nil },
 			}
 
 			// WHEN
@@ -334,11 +323,7 @@ func TestBackendServiceDescriber_URI(t *testing.T) {
 		}, nil)
 
 		d := &BackendServiceDescriber{
-			initClients: func(string) error { return nil },
-
-			ecsServiceDescribers: map[string]ecsDescriber{
-				"test": m,
-			},
+			initECSServiceDescribers: func(s string) (ecsDescriber, error) { return m, nil },
 		}
 
 		// WHEN
@@ -360,15 +345,9 @@ func TestBackendServiceDescriber_URI(t *testing.T) {
 		mockEnvStack.EXPECT().ServiceDiscoveryEndpoint().Return("test.app.local", nil)
 
 		d := &BackendServiceDescriber{
-			svc:         "hello",
-			initClients: func(string) error { return nil },
-
-			ecsServiceDescribers: map[string]ecsDescriber{
-				"test": mockSvcStack,
-			},
-			envStackDescriber: map[string]envDescriber{
-				"test": mockEnvStack,
-			},
+			svc:                      "hello",
+			initECSServiceDescribers: func(s string) (ecsDescriber, error) { return mockSvcStack, nil },
+			initEnvDescribers:        func(s string) (envDescriber, error) { return mockEnvStack, nil },
 		}
 
 		// WHEN
@@ -427,13 +406,9 @@ func TestRDWebServiceDescriber_URI(t *testing.T) {
 			tc.setupMocks(mocks)
 
 			d := &RDWebServiceDescriber{
-				app:         testApp,
-				svc:         testSvc,
-				initClients: func(string) error { return nil },
-
-				envSvcDescribers: map[string]apprunnerDescriber{
-					"test": mockSvcDescriber,
-				},
+				app:                    testApp,
+				svc:                    testSvc,
+				initAppRunnerDescriber: func(string) (apprunnerDescriber, error) { return mockSvcDescriber, nil },
 			}
 
 			// WHEN
