@@ -62,6 +62,8 @@ type LoadBalancedWebServiceConfig struct {
 	PublishConfig    PublishConfig                    `yaml:"publish"`
 	TaskDefOverrides []OverrideRule                   `yaml:"taskdef_overrides"`
 	NLBConfig        NetworkLoadBalancerConfiguration `yaml:"nlb"`
+	DeployConfig     DeploymentConfiguration          `yaml:"deployment"`
+	Observability    Observability                    `yaml:"observability"`
 }
 
 // LoadBalancedWebServiceProps contains properties for creating a new load balanced fargate service manifest.
@@ -134,7 +136,7 @@ func newDefaultLoadBalancedWebService() *LoadBalancedWebService {
 			},
 			Network: NetworkConfig{
 				VPC: vpcConfig{
-					Placement: &PublicSubnetPlacement,
+					Placement: placementP(PublicSubnetPlacement),
 				},
 			},
 		},
@@ -177,11 +179,6 @@ func (s *LoadBalancedWebService) EnvFile() string {
 	return aws.StringValue(s.TaskConfig.EnvFile)
 }
 
-// HasAliases returns true if the Load-Balanced Web Service uses aliases, either for ALB or NLB.
-func (s *LoadBalancedWebService) HasAliases() bool {
-	return !s.RoutingRule.Alias.IsEmpty() || !s.NLBConfig.Aliases.IsEmpty()
-}
-
 // ApplyEnv returns the service manifest with environment overrides.
 // If the environment passed in does not have any overrides then it returns itself.
 func (s LoadBalancedWebService) ApplyEnv(envName string) (WorkloadManifest, error) {
