@@ -72,7 +72,7 @@ func TestNewHTTPLoadBalancedWebService(t *testing.T) {
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement: &PublicSubnetPlacement,
+							Placement: placementP(PublicSubnetPlacement),
 						},
 					},
 				},
@@ -146,7 +146,7 @@ func TestNewHTTPLoadBalancedWebService(t *testing.T) {
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement: &PublicSubnetPlacement,
+							Placement: placementP(PublicSubnetPlacement),
 						},
 					},
 				},
@@ -418,9 +418,9 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							"LOG_LEVEL":      "DEBUG",
 							"DDB_TABLE_NAME": "awards",
 						},
-						Secrets: map[string]string{
-							"GITHUB_TOKEN": "1111",
-							"TWILIO_TOKEN": "1111",
+						Secrets: map[string]Secret{
+							"GITHUB_TOKEN": {from: aws.String("1111")},
+							"TWILIO_TOKEN": {from: aws.String("1111")},
 						},
 						Storage: Storage{
 							Volumes: map[string]*Volume{
@@ -454,7 +454,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement:      &PublicSubnetPlacement,
+							Placement:      placementP(PublicSubnetPlacement),
 							SecurityGroups: []string{"sg-123"},
 						},
 					},
@@ -516,8 +516,8 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							},
 						},
 						Logging: Logging{
-							SecretOptions: map[string]string{
-								"FOO": "BAR",
+							SecretOptions: map[string]Secret{
+								"FOO": {from: aws.String("BAR")},
 							},
 						},
 						Network: NetworkConfig{
@@ -567,9 +567,9 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 							"LOG_LEVEL":      "DEBUG",
 							"DDB_TABLE_NAME": "awards-prod",
 						},
-						Secrets: map[string]string{
-							"GITHUB_TOKEN": "1111",
-							"TWILIO_TOKEN": "1111",
+						Secrets: map[string]Secret{
+							"GITHUB_TOKEN": {from: aws.String("1111")},
+							"TWILIO_TOKEN": {from: aws.String("1111")},
 						},
 						Storage: Storage{
 							Volumes: map[string]*Volume{
@@ -609,13 +609,13 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Logging: Logging{
 						ConfigFile: aws.String("mockConfigFile"),
-						SecretOptions: map[string]string{
-							"FOO": "BAR",
+						SecretOptions: map[string]Secret{
+							"FOO": {from: aws.String("BAR")},
 						},
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement:      &PublicSubnetPlacement,
+							Placement:      placementP(PublicSubnetPlacement),
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -686,7 +686,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement:      &PublicSubnetPlacement,
+							Placement:      placementP(PublicSubnetPlacement),
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -710,7 +710,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Network: NetworkConfig{
 						VPC: vpcConfig{
-							Placement:      &PublicSubnetPlacement,
+							Placement:      placementP(PublicSubnetPlacement),
 							SecurityGroups: []string{"sg-456", "sg-789"},
 						},
 					},
@@ -1400,72 +1400,6 @@ func TestLoadBalancedWebService_BuildRequired(t *testing.T) {
 	}
 }
 
-func TestLoadBalancedWebService_HasAliases(t *testing.T) {
-	testCases := map[string]struct {
-		config LoadBalancedWebServiceConfig
-		want   bool
-	}{
-		"use http aliases": {
-			config: LoadBalancedWebServiceConfig{
-				RoutingRule: RoutingRuleConfigOrBool{
-					RoutingRuleConfiguration: RoutingRuleConfiguration{
-						Alias: Alias{
-							String: aws.String("mockAlias"),
-						},
-					},
-				},
-			},
-			want: true,
-		},
-		"use nlb aliases": {
-			config: LoadBalancedWebServiceConfig{
-				NLBConfig: NetworkLoadBalancerConfiguration{
-					Aliases: Alias{
-						StringSlice: []string{"mockAlias", "mockAnotherAlias"},
-					},
-				},
-			},
-			want: true,
-		},
-		"both http and nlb use aliases": {
-			config: LoadBalancedWebServiceConfig{
-				RoutingRule: RoutingRuleConfigOrBool{
-					RoutingRuleConfiguration: RoutingRuleConfiguration{
-						Alias: Alias{
-							StringSlice: []string{"mockAlias", "mockAnotherAlias"},
-						},
-					},
-				},
-				NLBConfig: NetworkLoadBalancerConfiguration{
-					Aliases: Alias{
-						String: aws.String("mockAlias"),
-					},
-				},
-			},
-			want: true,
-		},
-		"not using aliases": {
-			config: LoadBalancedWebServiceConfig{},
-			want:   false,
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			manifest := &LoadBalancedWebService{
-				LoadBalancedWebServiceConfig: tc.config,
-			}
-
-			// WHEN
-			got := manifest.HasAliases()
-
-			// THEN
-			require.Equal(t, tc.want, got)
-		})
-	}
-}
-
 func TestAlias_IsEmpty(t *testing.T) {
 	testCases := map[string]struct {
 		in     Alias
