@@ -153,13 +153,13 @@ func NewProvider(configs interface{}) (Provider, error) {
 type PipelineSchemaMajorVersion int
 
 const (
-	// Ver1 is the current schema major version of the pipeline.yml file.
+	// Ver1 is the current schema major version of the pipelines/*/manifest.yml file.
 	Ver1 PipelineSchemaMajorVersion = iota + 1
 )
 
-// PipelineManifest contains information that defines the relationship
+// Pipeline contains information that defines the relationship
 // and deployment ordering of your environments.
-type PipelineManifest struct {
+type Pipeline struct {
 	// Name of the pipeline
 	Name    string                     `yaml:"name"`
 	Version PipelineSchemaMajorVersion `yaml:"version"`
@@ -178,25 +178,38 @@ type Source struct {
 
 // Build defines the build project to build and test image.
 type Build struct {
-	Image string `yaml:"image"`
+	Image     string `yaml:"image"`
+	Buildspec string `yaml:"buildspec,omitempty"`
 }
 
 // PipelineStage represents a stage in the pipeline manifest
 type PipelineStage struct {
-	Name             string   `yaml:"name"`
-	RequiresApproval bool     `yaml:"requires_approval,omitempty"`
-	TestCommands     []string `yaml:"test_commands,omitempty"`
+	Name             string      `yaml:"name"`
+	RequiresApproval bool        `yaml:"requires_approval,omitempty"`
+	TestCommands     []string    `yaml:"test_commands,omitempty"`
+	Deployments      Deployments `yaml:"deployments,omitempty"`
 }
 
-// NewPipelineManifest returns a pipeline manifest object.
-func NewPipelineManifest(pipelineName string, provider Provider, stages []PipelineStage) (*PipelineManifest, error) {
+// Deployments represent a directed graph of cloudformation deployments.
+type Deployments map[string]*Deployment
+
+// Deployment is a cloudformation stack deployment configuration.
+type Deployment struct {
+	StackName      string   `yaml:"stack_name"`
+	TemplatePath   string   `yaml:"template_path"`
+	TemplateConfig string   `yaml:"template_config"`
+	DependsOn      []string `yaml:"depends_on"`
+}
+
+// NewPipeline returns a pipeline manifest object.
+func NewPipeline(pipelineName string, provider Provider, stages []PipelineStage) (*Pipeline, error) {
 	// TODO: #221 Do more validations
 	if len(stages) == 0 {
 		return nil, fmt.Errorf("a pipeline %s can not be created without a deployment stage",
 			pipelineName)
 	}
 
-	return &PipelineManifest{
+	return &Pipeline{
 		Name:    pipelineName,
 		Version: Ver1,
 		Source: &Source{
@@ -211,7 +224,7 @@ func NewPipelineManifest(pipelineName string, provider Provider, stages []Pipeli
 
 // MarshalBinary serializes the pipeline manifest object into byte array that
 // represents the pipeline.yml document.
-func (m *PipelineManifest) MarshalBinary() ([]byte, error) {
+func (m *Pipeline) MarshalBinary() ([]byte, error) {
 	content, err := m.parser.Parse(pipelineManifestPath, *m)
 	if err != nil {
 		return nil, err
@@ -222,8 +235,8 @@ func (m *PipelineManifest) MarshalBinary() ([]byte, error) {
 // UnmarshalPipeline deserializes the YAML input stream into a pipeline
 // manifest object. It returns an error if any issue occurs during
 // deserialization or the YAML input contains invalid fields.
-func UnmarshalPipeline(in []byte) (*PipelineManifest, error) {
-	pm := PipelineManifest{}
+func UnmarshalPipeline(in []byte) (*Pipeline, error) {
+	pm := Pipeline{}
 	err := yaml.Unmarshal(in, &pm)
 	if err != nil {
 		return nil, err
@@ -233,14 +246,12 @@ func UnmarshalPipeline(in []byte) (*PipelineManifest, error) {
 	if version, err = validateVersion(&pm); err != nil {
 		return nil, err
 	}
-
-	// TODO: #221 Do more validations
 	switch version {
 	case Ver1:
 		return &pm, nil
 	}
 	// we should never reach here, this is just to make the compiler happy
-	return nil, errors.New("unexpected error occurs while unmarshalling pipeline.yml")
+	return nil, errors.New("unexpected error occurs while unmarshalling manifest.yml")
 }
 
 // IsCodeStarConnection indicates to the manifest if this source requires a CSC connection.
@@ -255,7 +266,7 @@ func (s Source) IsCodeStarConnection() bool {
 	}
 }
 
-func validateVersion(pm *PipelineManifest) (PipelineSchemaMajorVersion, error) {
+func validateVersion(pm *Pipeline) (PipelineSchemaMajorVersion, error) {
 	switch pm.Version {
 	case Ver1:
 		return Ver1, nil
