@@ -33,11 +33,13 @@ const (
 )
 
 const (
+	// Protocols.
 	TCP = "TCP"
 	tls = "TLS"
-)
 
-var validProtocols = []string{TCP, tls}
+	// Tracing vendors.
+	awsXRAY = "awsxray"
+)
 
 var (
 	intRangeBandRegexp  = regexp.MustCompile(`^(\d+)-(\d+)$`)
@@ -49,6 +51,9 @@ var (
 
 	essentialContainerDependsOnValidStatuses = []string{dependsOnStart, dependsOnHealthy}
 	dependsOnValidStatuses                   = []string{dependsOnStart, dependsOnComplete, dependsOnSuccess, dependsOnHealthy}
+	nlbValidProtocols                        = []string{TCP, tls}
+	TracingValidVendors                      = []string{awsXRAY}
+	ecsRollingUpdateStrategies               = []string{ECSDefaultRollingUpdateStrategy, ECSRecreateRollingUpdateStrategy}
 
 	httpProtocolVersions = []string{"GRPC", "HTTP1", "HTTP2"}
 
@@ -89,6 +94,20 @@ func (l LoadBalancedWebService) Validate() error {
 	return nil
 }
 
+func (d DeploymentConfiguration) Validate() error {
+	if d.isEmpty() {
+		return nil
+	}
+	for _, validStrategy := range ecsRollingUpdateStrategies {
+		if strings.EqualFold(aws.StringValue(d.Rolling), validStrategy) {
+			return nil
+		}
+	}
+	return fmt.Errorf("invalid rolling deployment strategy %s, must be one of %s",
+		aws.StringValue(d.Rolling),
+		english.WordSeries(ecsRollingUpdateStrategies, "or"))
+}
+
 // Validate returns nil if LoadBalancedWebServiceConfig is configured correctly.
 func (l LoadBalancedWebServiceConfig) Validate() error {
 	var err error
@@ -150,12 +169,18 @@ func (l LoadBalancedWebServiceConfig) Validate() error {
 	if err = l.NLBConfig.Validate(); err != nil {
 		return fmt.Errorf(`validate "nlb": %w`, err)
 	}
+	if err = l.DeployConfig.Validate(); err != nil {
+		return fmt.Errorf(`validate "deployment": %w`, err)
+	}
 	return nil
 }
 
 // Validate returns nil if BackendService is configured correctly.
 func (b BackendService) Validate() error {
 	var err error
+	if err = b.DeployConfig.Validate(); err != nil {
+		return fmt.Errorf(`validate "deployment": %w`, err)
+	}
 	if err = b.BackendServiceConfig.Validate(); err != nil {
 		return err
 	}
@@ -249,12 +274,18 @@ func (r RequestDrivenWebServiceConfig) Validate() error {
 	if err = r.Network.Validate(); err != nil {
 		return fmt.Errorf(`validate "network": %w`, err)
 	}
+	if err = r.Observability.Validate(); err != nil {
+		return fmt.Errorf(`validate "observability": %w`, err)
+	}
 	return nil
 }
 
 // Validate returns nil if WorkerService is configured correctly.
 func (w WorkerService) Validate() error {
 	var err error
+	if err = w.DeployConfig.Validate(); err != nil {
+		return fmt.Errorf(`validate "deployment": %w`, err)
+	}
 	if err = w.WorkerServiceConfig.Validate(); err != nil {
 		return err
 	}
@@ -401,6 +432,39 @@ func (s ScheduledJobConfig) Validate() error {
 	return nil
 }
 
+// Validate returns nil if the pipeline manifest is configured correctly.
+func (p Pipeline) Validate() error {
+	if len(p.Name) > 100 {
+		return fmt.Errorf(`pipeline name '%s' must be shorter than 100 characters`, p.Name)
+	}
+	for _, stg := range p.Stages {
+		if err := stg.Deployments.Validate(); err != nil {
+			return fmt.Errorf(`validate "deployments" for pipeline stage %s: %w`, stg.Name, err)
+		}
+	}
+	return nil
+}
+
+// Validate returns nil if deployments are configured correctly.
+func (d Deployments) Validate() error {
+	names := make(map[string]bool)
+	for name, _ := range d {
+		names[name] = true
+	}
+
+	for name, conf := range d {
+		if conf == nil {
+			continue
+		}
+		for _, dependency := range conf.DependsOn {
+			if _, ok := names[dependency]; !ok {
+				return fmt.Errorf("dependency deployment named '%s' of '%s' does not exist", dependency, name)
+			}
+		}
+	}
+	return nil
+}
+
 // Validate returns nil if Workload is configured correctly.
 func (w Workload) Validate() error {
 	if w.Name == nil {
@@ -662,14 +726,14 @@ func validateNLBPort(port *string) error {
 	}
 	protocolVal := aws.StringValue(protocol)
 	var isValidProtocol bool
-	for _, valid := range validProtocols {
+	for _, valid := range nlbValidProtocols {
 		if strings.EqualFold(protocolVal, valid) {
 			isValidProtocol = true
 			break
 		}
 	}
 	if !isValidProtocol {
-		return fmt.Errorf(`invalid protocol %s; valid protocols include %s`, protocolVal, english.WordSeries(validProtocols, "and"))
+		return fmt.Errorf(`invalid protocol %s; valid protocols include %s`, protocolVal, english.WordSeries(nlbValidProtocols, "and"))
 	}
 	return nil
 }
@@ -1144,6 +1208,22 @@ func (r RequestDrivenWebServiceHttpConfig) Validate() error {
 	return r.HealthCheckConfiguration.Validate()
 }
 
+// Validate returns nil if Observability is configured correctly.
+func (o Observability) Validate() error {
+	if o.isEmpty() {
+		return nil
+	}
+	for _, validVendor := range TracingValidVendors {
+		if strings.EqualFold(aws.StringValue(o.Tracing), validVendor) {
+			return nil
+		}
+	}
+	return fmt.Errorf("invalid tracing vendor %s: %s %s",
+		aws.StringValue(o.Tracing),
+		english.PluralWord(len(TracingValidVendors), "the valid vendor is", "valid vendors are"),
+		english.WordSeries(TracingValidVendors, "and"))
+}
+
 // Validate returns nil if JobTriggerConfig is configured correctly.
 func (c JobTriggerConfig) Validate() error {
 	if c.Schedule == nil {
@@ -1248,6 +1328,11 @@ func (r OverrideRule) Validate() error {
 	return nil
 }
 
+// Validate is a no-op for Secrets.
+func (s Secret) Validate() error {
+	return nil
+}
+
 type validateDependenciesOpts struct {
 	mainContainerName string
 	sidecarConfig     map[string]*SidecarConfig
@@ -1350,19 +1435,19 @@ func validateNoCircularDependencies(deps map[string]containerDependency) error {
 	if len(cycle) == 1 {
 		return fmt.Errorf("container %s cannot depend on itself", cycle[0])
 	}
-	// Stablize unit tests.
+	// Stabilize unit tests.
 	sort.SliceStable(cycle, func(i, j int) bool { return cycle[i] < cycle[j] })
 	return fmt.Errorf("circular container dependency chain includes the following containers: %s", cycle)
 }
 
-func buildDependencyGraph(deps map[string]containerDependency) (*graph.Graph, error) {
-	dependencyGraph := graph.New()
+func buildDependencyGraph(deps map[string]containerDependency) (*graph.Graph[string], error) {
+	dependencyGraph := graph.New[string]()
 	for name, containerDep := range deps {
 		for dep := range containerDep.dependsOn {
 			if _, ok := deps[dep]; !ok {
 				return nil, fmt.Errorf("container %s does not exist", dep)
 			}
-			dependencyGraph.Add(graph.Edge{
+			dependencyGraph.Add(graph.Edge[string]{
 				From: name,
 				To:   dep,
 			})
