@@ -71,7 +71,8 @@ const (
 	taskFinalMsg        = "Task:"
 	workloadFinalMsg    = "Name:"
 	dockerfileFinalMsg  = "Dockerfile:"
-	topicFinalmessage   = "Topic subscriptions:"
+	topicFinalMsg       = "Topic subscriptions:"
+	pipelineFinalMsg    = "Pipeline:"
 )
 
 var scheduleTypes = []string{
@@ -123,6 +124,16 @@ type WsWorkloadLister interface {
 	ListWorkloads() ([]string, error)
 }
 
+// WsPipelinesLister is a pipeline lister.
+type WsPipelinesLister interface {
+	ListPipelines() ([]workspace.PipelineManifest, error)
+}
+
+// CodePipelineLister is a pipeline lister for deployed pipelines.
+type CodePipelineLister interface {
+	ListDeployedPipelines(appName string) ([]deploy.Pipeline, error)
+}
+
 // WorkspaceRetriever wraps methods to get workload names, app names, and Dockerfiles from the workspace.
 type WorkspaceRetriever interface {
 	WsWorkloadLister
@@ -170,6 +181,24 @@ type WorkspaceSelect struct {
 	appName string
 }
 
+// WsPipelineSelect is a workspace pipeline selector.
+type WsPipelineSelect struct {
+	prompt Prompter
+	ws     WsPipelinesLister
+}
+
+// CodePipelineSelect is a selector for deployed pipelines.
+type CodePipelineSelect struct {
+	prompt         Prompter
+	pipelineLister CodePipelineLister
+}
+
+// AppPipelineSelect is a selector for deployed pipelines and apps.
+type AppPipelineSelect struct {
+	*Select
+	*CodePipelineSelect
+}
+
 // DeploySelect is a service and environment selector from the deploy store.
 type DeploySelect struct {
 	*Select
@@ -249,6 +278,25 @@ func NewWorkspaceSelect(prompt Prompter, store ConfigLister, ws WorkspaceRetriev
 	}
 }
 
+// NewWsPipelineSelect returns a new selector with pipelines from the local workspace.
+func NewWsPipelineSelect(prompt Prompter, ws WsPipelinesLister) *WsPipelineSelect {
+	return &WsPipelineSelect{
+		prompt: prompt,
+		ws:     ws,
+	}
+}
+
+// NewAppPipelineSelect returns new selectors with deployed pipelines and apps.
+func NewAppPipelineSelect(prompt Prompter, store ConfigLister, lister CodePipelineLister) *AppPipelineSelect {
+	return &AppPipelineSelect{
+		Select: NewSelect(prompt, store),
+		CodePipelineSelect: &CodePipelineSelect{
+			prompt:         prompt,
+			pipelineLister: lister,
+		},
+	}
+}
+
 // NewDeploySelect returns a new selector that chooses services and environments from the deploy store.
 func NewDeploySelect(prompt Prompter, configStore ConfigLister, deployStore DeployStoreClient) *DeploySelect {
 	return &DeploySelect{
@@ -673,6 +721,63 @@ func filterWlsByName(wls []*config.Workload, wantedNames []string) []string {
 	return filtered
 }
 
+// WsPipeline fetches all the pipelines in a workspace and prompts the user to select one.
+func (s *WsPipelineSelect) WsPipeline(msg, help string) (*workspace.PipelineManifest, error) {
+	pipelines, err := s.ws.ListPipelines()
+	if err != nil {
+		return nil, fmt.Errorf("list pipelines: %w", err)
+	}
+	if len(pipelines) == 0 {
+		return nil, errors.New("no pipelines found")
+	}
+	var pipelineNames []string
+	for _, pipeline := range pipelines {
+		pipelineNames = append(pipelineNames, pipeline.Name)
+	}
+	if len(pipelineNames) == 1 {
+		log.Infof("Only found one pipeline; defaulting to: %s\n", color.HighlightUserInput(pipelineNames[0]))
+		return &workspace.PipelineManifest{
+			Name: pipelines[0].Name,
+			Path: pipelines[0].Path,
+		}, nil
+	}
+	selectedPipeline, err := s.prompt.SelectOne(msg, help, pipelineNames, prompt.WithFinalMessage(pipelineFinalMsg))
+	if err != nil {
+		return nil, fmt.Errorf("select pipeline: %w", err)
+	}
+	return &workspace.PipelineManifest{
+		Name: selectedPipeline,
+		Path: s.pipelinePath(pipelines, selectedPipeline),
+	}, nil
+}
+
+// DeployedPipeline fetches all the pipelines in a workspace and prompts the user to select one.
+func (s *CodePipelineSelect) DeployedPipeline(msg, help, app string) (deploy.Pipeline, error) {
+	pipelines, err := s.pipelineLister.ListDeployedPipelines(app)
+	if err != nil {
+		return deploy.Pipeline{}, fmt.Errorf("list deployed pipelines: %w", err)
+	}
+	if len(pipelines) == 0 {
+		return deploy.Pipeline{}, errors.New("no deployed pipelines found")
+	}
+	if len(pipelines) == 1 {
+		log.Infof("Only one deployed pipeline found; defaulting to: %s\n", color.HighlightUserInput(pipelines[0].Name))
+		return pipelines[0], nil
+	}
+
+	var pipelineNames []string
+	pipelineNameToInfo := make(map[string]deploy.Pipeline)
+	for _, pipeline := range pipelines {
+		pipelineNames = append(pipelineNames, pipeline.Name)
+		pipelineNameToInfo[pipeline.Name] = pipeline
+	}
+	selectedPipeline, err := s.prompt.SelectOne(msg, help, pipelineNames, prompt.WithFinalMessage(pipelineFinalMsg))
+	if err != nil {
+		return deploy.Pipeline{}, fmt.Errorf("select pipeline: %w", err)
+	}
+	return pipelineNameToInfo[selectedPipeline], nil
+}
+
 // Service fetches all services in an app and prompts the user to select one.
 func (s *ConfigSelect) Service(msg, help, app string) (string, error) {
 	services, err := s.retrieveServices(app)
@@ -793,7 +898,6 @@ func (s *Select) Application(msg, help string, additionalOpts ...string) (string
 		return "", err
 	}
 
-	appNames = append(appNames, additionalOpts...)
 	if len(appNames) == 0 {
 		log.Infof("Couldn't find any applications in this region and account. Try initializing one with %s\n",
 			color.HighlightCode("copilot app init"))
@@ -805,6 +909,7 @@ func (s *Select) Application(msg, help string, additionalOpts ...string) (string
 		return appNames[0], nil
 	}
 
+	appNames = append(appNames, additionalOpts...)
 	app, err := s.prompt.SelectOne(msg, help, appNames, prompt.WithFinalMessage(appNameFinalMessage))
 	if err != nil {
 		return "", fmt.Errorf("select application: %w", err)
@@ -812,6 +917,128 @@ func (s *Select) Application(msg, help string, additionalOpts ...string) (string
 	return app, nil
 }
 
+// Dockerfile asks the user to select from a list of Dockerfiles in the current
+// directory or one level down. If no dockerfiles are found, it asks for a custom path.
+func (s *WorkspaceSelect) Dockerfile(selPrompt, notFoundPrompt, selHelp, notFoundHelp string, pathValidator prompt.ValidatorFunc) (string, error) {
+	dockerfiles, err := s.ws.ListDockerfiles()
+	if err != nil {
+		return "", fmt.Errorf("list Dockerfiles: %w", err)
+	}
+	var sel string
+	dockerfiles = append(dockerfiles, []string{dockerfilePromptUseCustom, DockerfilePromptUseImage}...)
+	sel, err = s.prompt.SelectOne(
+		selPrompt,
+		selHelp,
+		dockerfiles,
+		prompt.WithFinalMessage(dockerfileFinalMsg),
+	)
+	if err != nil {
+		return "", fmt.Errorf("select Dockerfile: %w", err)
+	}
+	if sel != dockerfilePromptUseCustom {
+		return sel, nil
+	}
+	sel, err = s.prompt.Get(
+		notFoundPrompt,
+		notFoundHelp,
+		pathValidator,
+		prompt.WithFinalMessage(dockerfileFinalMsg))
+	if err != nil {
+		return "", fmt.Errorf("get custom Dockerfile path: %w", err)
+	}
+	return sel, nil
+}
+
+// Schedule asks the user to select either a rate, preset cron, or custom cron.
+func (s *WorkspaceSelect) Schedule(scheduleTypePrompt, scheduleTypeHelp string, scheduleValidator, rateValidator prompt.ValidatorFunc) (string, error) {
+	scheduleType, err := s.prompt.SelectOne(
+		scheduleTypePrompt,
+		scheduleTypeHelp,
+		scheduleTypes,
+		prompt.WithFinalMessage("Schedule type:"),
+	)
+	if err != nil {
+		return "", fmt.Errorf("get schedule type: %w", err)
+	}
+	switch scheduleType {
+	case rate:
+		return s.askRate(rateValidator)
+	case fixedSchedule:
+		return s.askCron(scheduleValidator)
+	default:
+		return "", fmt.Errorf("unrecognized schedule type %s", scheduleType)
+	}
+}
+
+// Topics asks the user to select from all Copilot-managed SNS topics *which are deployed
+// across all environments* and returns the topic structs.
+func (s *DeploySelect) Topics(promptMsg, help, app string) ([]deploy.Topic, error) {
+	envs, err := s.config.ListEnvironments(app)
+	if err != nil {
+		return nil, fmt.Errorf("list environments: %w", err)
+	}
+	if len(envs) == 0 {
+		log.Infoln("No environments are currently deployed. Skipping subscription selection.")
+		return nil, nil
+	}
+
+	envTopics := make(map[string][]deploy.Topic, len(envs))
+	for _, env := range envs {
+		topics, err := s.deployStoreSvc.ListSNSTopics(app, env.Name)
+		if err != nil {
+			return nil, fmt.Errorf("list SNS topics: %w", err)
+		}
+		envTopics[env.Name] = topics
+	}
+
+	// Get only topics deployed in all environments.
+	// Computes the intersection of the `envTopics` lists.
+	overallTopics := make(map[string]deploy.Topic)
+	// Initialize the list of topics.
+	for _, topic := range envTopics[envs[0].Name] {
+		overallTopics[topic.String()] = topic
+	}
+	// Then do the pairwise intersection of all other envs.
+	for _, env := range envs[1:] {
+		topics := envTopics[env.Name]
+		overallTopics = intersect(overallTopics, topics)
+	}
+
+	if len(overallTopics) == 0 {
+		log.Infoln("No SNS topics are currently deployed in all environments. You can customize subscriptions in your manifest.")
+		return nil, nil
+	}
+	// Create the list of options.
+	var topicDescriptions []string
+	for t := range overallTopics {
+		topicDescriptions = append(topicDescriptions, t)
+	}
+	// Sort descriptions by ARN, which implies sorting by workload name and then by topic name due to
+	// behavior of `intersect`. That is, the `overallTopics` map is guaranteed to contain topics
+	// referencing the same environment.
+	sort.Slice(topicDescriptions, func(i, j int) bool {
+		return overallTopics[topicDescriptions[i]].ARN() < overallTopics[topicDescriptions[j]].ARN()
+	})
+
+	selectedTopics, err := s.prompt.MultiSelect(
+		promptMsg,
+		help,
+		topicDescriptions,
+		nil,
+		prompt.WithFinalMessage(topicFinalMsg),
+	)
+	if err != nil {
+		return nil, fmt.Errorf("select SNS topics: %w", err)
+	}
+
+	// Get the topics from the topic descriptions again.
+	var topics []deploy.Topic
+	for _, t := range selectedTopics {
+		topics = append(topics, overallTopics[t])
+	}
+	return topics, nil
+}
+
 func (s *Select) retrieveApps() ([]string, error) {
 	apps, err := s.config.ListApplications()
 	if err != nil {
@@ -884,57 +1111,13 @@ func (s *WorkspaceSelect) retrieveWorkspaceWorkloads() ([]string, error) {
 	return localWlNames, nil
 }
 
-// Dockerfile asks the user to select from a list of Dockerfiles in the current
-// directory or one level down. If no dockerfiles are found, it asks for a custom path.
-func (s *WorkspaceSelect) Dockerfile(selPrompt, notFoundPrompt, selHelp, notFoundHelp string, pathValidator prompt.ValidatorFunc) (string, error) {
-	dockerfiles, err := s.ws.ListDockerfiles()
-	if err != nil {
-		return "", fmt.Errorf("list Dockerfiles: %w", err)
-	}
-	var sel string
-	dockerfiles = append(dockerfiles, []string{dockerfilePromptUseCustom, DockerfilePromptUseImage}...)
-	sel, err = s.prompt.SelectOne(
-		selPrompt,
-		selHelp,
-		dockerfiles,
-		prompt.WithFinalMessage(dockerfileFinalMsg),
-	)
-	if err != nil {
-		return "", fmt.Errorf("select Dockerfile: %w", err)
-	}
-	if sel != dockerfilePromptUseCustom {
-		return sel, nil
-	}
-	sel, err = s.prompt.Get(
-		notFoundPrompt,
-		notFoundHelp,
-		pathValidator,
-		prompt.WithFinalMessage(dockerfileFinalMsg))
-	if err != nil {
-		return "", fmt.Errorf("get custom Dockerfile path: %w", err)
-	}
-	return sel, nil
-}
-
-// Schedule asks the user to select either a rate, preset cron, or custom cron.
-func (s *WorkspaceSelect) Schedule(scheduleTypePrompt, scheduleTypeHelp string, scheduleValidator, rateValidator prompt.ValidatorFunc) (string, error) {
-	scheduleType, err := s.prompt.SelectOne(
-		scheduleTypePrompt,
-		scheduleTypeHelp,
-		scheduleTypes,
-		prompt.WithFinalMessage("Schedule type:"),
-	)
-	if err != nil {
-		return "", fmt.Errorf("get schedule type: %w", err)
-	}
-	switch scheduleType {
-	case rate:
-		return s.askRate(rateValidator)
-	case fixedSchedule:
-		return s.askCron(scheduleValidator)
-	default:
-		return "", fmt.Errorf("unrecognized schedule type %s", scheduleType)
+func (s *WsPipelineSelect) pipelinePath(pipelines []workspace.PipelineManifest, name string) string {
+	for _, pipeline := range pipelines {
+		if pipeline.Name == name {
+			return pipeline.Path
+		}
 	}
+	return ""
 }
 
 func (s *WorkspaceSelect) askRate(rateValidator prompt.ValidatorFunc) (string, error) {
@@ -1024,75 +1207,6 @@ func filterDeployedServices(filter DeployedServiceFilter, inServices []*Deployed
 	return outServices, nil
 }
 
-// Topics asks the user to select from all Copilot-managed SNS topics *which are deployed
-// across all environments* and returns the topic structs.
-func (s *DeploySelect) Topics(promptMsg, help, app string) ([]deploy.Topic, error) {
-	envs, err := s.config.ListEnvironments(app)
-	if err != nil {
-		return nil, fmt.Errorf("list environments: %w", err)
-	}
-	if len(envs) == 0 {
-		log.Infoln("No environments are currently deployed. Skipping subscription selection.")
-		return nil, nil
-	}
-
-	envTopics := make(map[string][]deploy.Topic, len(envs))
-	for _, env := range envs {
-		topics, err := s.deployStoreSvc.ListSNSTopics(app, env.Name)
-		if err != nil {
-			return nil, fmt.Errorf("list SNS topics: %w", err)
-		}
-		envTopics[env.Name] = topics
-	}
-
-	// Get only topics deployed in all environments.
-	// Computes the intersection of the `envTopics` lists.
-	overallTopics := make(map[string]deploy.Topic)
-	// Initialize the list of topics.
-	for _, topic := range envTopics[envs[0].Name] {
-		overallTopics[topic.String()] = topic
-	}
-	// Then do the pairwise intersection of all other envs.
-	for _, env := range envs[1:] {
-		topics := envTopics[env.Name]
-		overallTopics = intersect(overallTopics, topics)
-	}
-
-	if len(overallTopics) == 0 {
-		log.Infoln("No SNS topics are currently deployed in all environments. You can customize subscriptions in your manifest.")
-		return nil, nil
-	}
-	// Create the list of options.
-	var topicDescriptions []string
-	for t := range overallTopics {
-		topicDescriptions = append(topicDescriptions, t)
-	}
-	// Sort descriptions by ARN, which implies sorting by workload name and then by topic name due to
-	// behavior of `intersect`. That is, the `overallTopics` map is guaranteed to contain topics
-	// referencing the same environment.
-	sort.Slice(topicDescriptions, func(i, j int) bool {
-		return overallTopics[topicDescriptions[i]].ARN() < overallTopics[topicDescriptions[j]].ARN()
-	})
-
-	selectedTopics, err := s.prompt.MultiSelect(
-		promptMsg,
-		help,
-		topicDescriptions,
-		nil,
-		prompt.WithFinalMessage(topicFinalmessage),
-	)
-	if err != nil {
-		return nil, fmt.Errorf("select SNS topics: %w", err)
-	}
-
-	// Get the topics from the topic descriptions again.
-	var topics []deploy.Topic
-	for _, t := range selectedTopics {
-		topics = append(topics, overallTopics[t])
-	}
-	return topics, nil
-}
-
 func intersect(firstMap map[string]deploy.Topic, secondArr []deploy.Topic) map[string]deploy.Topic {
 	out := make(map[string]deploy.Topic)
 	for _, topic := range secondArr {
