@@ -117,8 +117,11 @@ func TestWorkspace_Summary(t *testing.T) {
 		mockFileSystem  func(fs afero.Fs)
 	}{
 		"existing workspace summary": {
-			expectedSummary: Summary{Application: "DavidsApp"},
-			workingDir:      "test/",
+			expectedSummary: Summary{
+				Application: "DavidsApp",
+				Path:        "test/copilot/.workspace",
+			},
+			workingDir: "test/",
 			mockFileSystem: func(fs afero.Fs) {
 				fs.MkdirAll("test/copilot", 0755)
 				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
@@ -189,7 +192,7 @@ func TestWorkspace_Create(t *testing.T) {
 		"existing workspace and different application": {
 			workingDir:    "test/",
 			appName:       "DavidsApp",
-			expectedError: fmt.Errorf("this workspace is already registered with application DavidsOtherApp"),
+			expectedError: fmt.Errorf("workspace is already registered with application DavidsOtherApp under copilot/.workspace"),
 			mockFileSystem: func(fs afero.Fs) {
 				fs.MkdirAll("test/copilot", 0755)
 				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsOtherApp")), 0644)
@@ -509,6 +512,221 @@ type: Scheduled Job`))
 	}
 }
 
+func TestWorkspace_ListPipelines(t *testing.T) {
+	testCases := map[string]struct {
+		copilotDir string
+		fs         func() afero.Fs
+
+		wantedPipelines []PipelineManifest
+		wantedErr       error
+		wantedLog       string
+	}{
+		"success finding legacy pipeline (copilot/pipeline.yml) and pipelines (copilot/pipelines/*/manifest.yml)": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+
+				fs.Mkdir("/copilot", 0755)
+				fs.Create("/copilot/buildspec.yml")
+				legacyInCopiDirManifest, _ := fs.Create("/copilot/pipeline.yml")
+				defer legacyInCopiDirManifest.Close()
+				legacyInCopiDirManifest.Write([]byte(`
+name: legacyInCopiDir
+version: 1
+`))
+
+				fs.Mkdir("/copilot/pipelines", 0755)
+				fs.Create("/copilot/pipelines/randomFileToIgnore.yml")
+
+				fs.Create("/copilot/pipelines/beta/buildspec.yml")
+				betaPipelineManifest, _ := fs.Create("/copilot/pipelines/beta/manifest.yml")
+				defer betaPipelineManifest.Close()
+				betaPipelineManifest.Write([]byte(`
+name: betaManifest
+version: 1
+`))
+
+				fs.Create("/copilot/pipelines/prod/buildspec.yml")
+				prodPipelineManifest, _ := fs.Create("/copilot/pipelines/prod/manifest.yml")
+				defer prodPipelineManifest.Close()
+				prodPipelineManifest.Write([]byte(`
+name: prodManifest
+version: 1
+`))
+
+				return fs
+			},
+			wantedPipelines: []PipelineManifest{
+				{
+					Name: "betaManifest",
+					Path: "/copilot/pipelines/beta/manifest.yml",
+				},
+				{
+					Name: "legacyInCopiDir",
+					Path: "/copilot/pipeline.yml",
+				},
+				{
+					Name: "prodManifest",
+					Path: "/copilot/pipelines/prod/manifest.yml",
+				},
+			},
+
+			wantedErr: nil,
+		},
+		"success finding legacy pipeline if it is the only pipeline": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+
+				fs.Mkdir("/copilot", 0755)
+				fs.Create("/copilot/buildspec.yml")
+				legacyInCopiDirManifest, _ := fs.Create("/copilot/pipeline.yml")
+				defer legacyInCopiDirManifest.Close()
+				legacyInCopiDirManifest.Write([]byte(`
+name: legacyInCopiDir
+version: 1
+`))
+
+				return fs
+			},
+			wantedPipelines: []PipelineManifest{
+				{
+					Name: "legacyInCopiDir",
+					Path: "/copilot/pipeline.yml",
+				},
+			},
+			wantedErr: nil,
+		},
+		"success finding pipelines without any legacy pipelines": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+
+				fs.Mkdir("/copilot", 0755)
+				fs.Mkdir("/copilot/pipelines", 0755)
+
+				fs.Create("/copilot/pipelines/beta/buildspec.yml")
+				betaPipelineManifest, _ := fs.Create("/copilot/pipelines/beta/manifest.yml")
+				defer betaPipelineManifest.Close()
+				betaPipelineManifest.Write([]byte(`
+name: betaManifest
+version: 1
+`))
+
+				fs.Create("/copilot/pipelines/prod/buildspec.yml")
+				prodPipelineManifest, _ := fs.Create("/copilot/pipelines/prod/manifest.yml")
+				defer prodPipelineManifest.Close()
+				prodPipelineManifest.Write([]byte(`
+name: prodManifest
+version: 1
+`))
+
+				return fs
+			},
+			wantedPipelines: []PipelineManifest{
+				{
+					Name: "betaManifest",
+					Path: "/copilot/pipelines/beta/manifest.yml",
+				},
+				{
+					Name: "prodManifest",
+					Path: "/copilot/pipelines/prod/manifest.yml",
+				},
+			},
+			wantedErr: nil,
+		},
+		"ignores missing manifest files": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+
+				fs.Mkdir("/copilot", 0755)
+				fs.Mkdir("/copilot/pipelines", 0755)
+				fs.Mkdir("/copilot/pipelines/beta", 0755)
+				fs.Mkdir("/copilot/pipelines/prod", 0755)
+
+				return fs
+			},
+			wantedPipelines: nil,
+			wantedErr:       nil,
+		},
+		"ignores pipeline manifest with invalid version": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+
+				fs.Mkdir("/copilot", 0755)
+				fs.Mkdir("/copilot/pipelines", 0755)
+				fs.Mkdir("/copilot/pipelines/beta", 0755)
+				fs.Create("/copilot/pipelines/beta/buildspec.yml")
+				betaPipelineManifest, _ := fs.Create("/copilot/pipelines/beta/manifest.yml")
+				defer betaPipelineManifest.Close()
+				betaPipelineManifest.Write([]byte(`
+name: betaManifest
+version: invalidVersionShouldBe~int
+`))
+
+				fs.Mkdir("/copilot/pipelines/prod", 0755)
+				fs.Create("/copilot/pipelines/prod/buildspec.yml")
+				prodPipelineManifest, _ := fs.Create("/copilot/pipelines/prod/manifest.yml")
+				defer prodPipelineManifest.Close()
+				prodPipelineManifest.Write([]byte(`
+name: prodManifest
+version: 1
+`))
+
+				return fs
+			},
+			wantedPipelines: []PipelineManifest{
+				{
+					Name: "prodManifest",
+					Path: "/copilot/pipelines/prod/manifest.yml",
+				},
+			},
+			wantedErr: nil,
+			wantedLog: "Unable to read pipeline manifest at '/copilot/pipelines/beta/manifest.yml': unmarshal pipeline manifest: yaml: unmarshal errors:\n  line 3: cannot unmarshal !!str `invalid...` into manifest.PipelineSchemaMajorVersion\n",
+		},
+		"handles missing copilot directory error": {
+			copilotDir: "",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				return fs
+			},
+			wantedPipelines: nil,
+			wantedErr: &ErrWorkspaceNotFound{
+				ManifestDirectoryName: CopilotDirName,
+				NumberOfLevelsChecked: maximumParentDirsToSearch,
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		var log string
+		logCollector := func(format string, a ...interface{}) {
+			log += fmt.Sprintf(format, a...)
+		}
+
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDir: tc.copilotDir,
+				fsUtils: &afero.Afero{
+					Fs: tc.fs(),
+				},
+				logger: logCollector,
+			}
+
+			pipelines, err := ws.ListPipelines()
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedPipelines, pipelines)
+			}
+			require.Equal(t, tc.wantedLog, log)
+		})
+	}
+}
+
 func TestIsInGitRepository(t *testing.T) {
 	testCases := map[string]struct {
 		given  func() FileStat
@@ -542,114 +760,6 @@ func TestIsInGitRepository(t *testing.T) {
 	}
 }
 
-func TestWorkspace_read(t *testing.T) {
-	testCases := map[string]struct {
-		elems []string
-
-		copilotDir string
-		fs         func() afero.Fs
-
-		wantedData []byte
-		wantedErr  error
-	}{
-		"return error if file does not exist": {
-			elems: []string{"webhook", "manifest.yml"},
-
-			copilotDir: "/copilot",
-			fs: func() afero.Fs {
-				fs := afero.NewMemMapFs()
-				return fs
-			},
-
-			wantedErr: fmt.Errorf("file /copilot/webhook/manifest.yml does not exists"),
-		},
-		"read existing file": {
-			elems: []string{"webhook", "manifest.yml"},
-
-			copilotDir: "/copilot",
-			fs: func() afero.Fs {
-				fs := afero.NewMemMapFs()
-				fs.MkdirAll("/copilot/webhook/", 0755)
-				f, _ := fs.Create("/copilot/webhook/manifest.yml")
-				defer f.Close()
-				f.Write([]byte("hello"))
-				return fs
-			},
-
-			wantedData: []byte("hello"),
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			ws := &Workspace{
-				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
-					Fs: tc.fs(),
-				},
-			}
-
-			data, err := ws.read(tc.elems...)
-
-			if tc.wantedErr == nil {
-				require.NoError(t, err)
-				require.Equal(t, tc.wantedData, data)
-			} else {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			}
-		})
-	}
-}
-
-func TestWorkspace_write(t *testing.T) {
-	testCases := map[string]struct {
-		elems []string
-
-		wantedPath string
-		wantedErr  error
-	}{
-		"create file under nested directories": {
-			elems:      []string{"webhook", "addons", "policy.yml"},
-			wantedPath: "/copilot/webhook/addons/policy.yml",
-		},
-		"create file under copilot directory": {
-			elems:      []string{pipelineFileName},
-			wantedPath: "/copilot/pipeline.yml",
-		},
-		"return ErrFileExists if file already exists": {
-			elems:     []string{"manifest.yml"},
-			wantedErr: &ErrFileExists{FileName: "/copilot/manifest.yml"},
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			fs := afero.NewMemMapFs()
-			utils := &afero.Afero{
-				Fs: fs,
-			}
-			utils.MkdirAll("/copilot", 0755)
-			utils.WriteFile("/copilot/manifest.yml", []byte{}, 0644)
-			ws := &Workspace{
-				workingDir: "/",
-				copilotDir: "/copilot",
-				fsUtils:    utils,
-			}
-
-			// WHEN
-			actualPath, actualErr := ws.write(nil, tc.elems...)
-
-			// THEN
-			if tc.wantedErr != nil {
-				require.EqualError(t, actualErr, tc.wantedErr.Error(), "expected the same error")
-			} else {
-				require.Equal(t, tc.wantedPath, actualPath, "expected the same path")
-			}
-		})
-	}
-}
-
 func TestWorkspace_ReadAddonsDir(t *testing.T) {
 	testCases := map[string]struct {
 		svcName        string
@@ -777,10 +887,13 @@ func TestWorkspace_ReadPipelineManifest(t *testing.T) {
 		"reads existing pipeline manifest": {
 			fs: func() afero.Fs {
 				fs := afero.NewMemMapFs()
-				fs.MkdirAll("/copilot", 0755)
-				manifest, _ := fs.Create("/copilot/pipeline.yml")
+				fs.MkdirAll(copilotDir, 0755)
+				manifest, _ := fs.Create("/copilot/pipelines/my-pipeline/manifest.yml")
 				defer manifest.Close()
-				manifest.Write([]byte("hello"))
+				manifest.Write([]byte(`
+name: somePipelineName
+version: 1
+`))
 				return fs
 			},
 			expectedError: nil,
@@ -794,6 +907,20 @@ func TestWorkspace_ReadPipelineManifest(t *testing.T) {
 			},
 			expectedError: ErrNoPipelineInWorkspace,
 		},
+		"error unmarshaling pipeline manifest": {
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll(copilotDir, 0755)
+				manifest, _ := fs.Create("/copilot/pipelines/my-pipeline/manifest.yml")
+				defer manifest.Close()
+				manifest.Write([]byte(`
+name: somePipelineName
+version: 0
+`))
+				return fs
+			},
+			expectedError: errors.New("unmarshal pipeline manifest: pipeline manifest contains invalid schema version: 0"),
+		},
 	}
 
 	for name, tc := range testCases {
@@ -806,7 +933,7 @@ func TestWorkspace_ReadPipelineManifest(t *testing.T) {
 			}
 
 			// WHEN
-			_, err := ws.ReadPipelineManifest()
+			_, err := ws.ReadPipelineManifest("/copilot/pipelines/my-pipeline/manifest.yml")
 
 			// THEN
 			if tc.expectedError != nil {
@@ -886,6 +1013,20 @@ func TestWorkspace_ListDockerfiles(t *testing.T) {
 			err:         nil,
 			dockerfiles: wantedDockerfiles,
 		},
+		"exclude dockerignore files": {
+			mockFileSystem: func(mockFS afero.Fs) {
+				mockFS.MkdirAll("frontend", 0755)
+				mockFS.MkdirAll("backend", 0755)
+
+				afero.WriteFile(mockFS, "Dockerfile", []byte("FROM nginx"), 0644)
+				afero.WriteFile(mockFS, "frontend/Dockerfile", []byte("FROM nginx"), 0644)
+				afero.WriteFile(mockFS, "frontend/Dockerfile.dockerignore", []byte("*/temp*"), 0644)
+				afero.WriteFile(mockFS, "backend/Dockerfile", []byte("FROM nginx"), 0644)
+				afero.WriteFile(mockFS, "backend/Dockerfile.dockerignore", []byte("*/temp*"), 0644)
+			},
+			err:         nil,
+			dockerfiles: wantedDockerfiles,
+		},
 		"nonstandard Dockerfile names": {
 			mockFileSystem: func(mockFS afero.Fs) {
 				mockFS.MkdirAll("frontend", 0755)
@@ -893,6 +1034,7 @@ func TestWorkspace_ListDockerfiles(t *testing.T) {
 				afero.WriteFile(mockFS, "Dockerfile", []byte("FROM nginx"), 0644)
 				afero.WriteFile(mockFS, "frontend/dockerfile", []byte("FROM nginx"), 0644)
 				afero.WriteFile(mockFS, "Job.dockerfile", []byte("FROM nginx"), 0644)
+				afero.WriteFile(mockFS, "Job.dockerfile.dockerignore", []byte("*/temp*"), 0644)
 			},
 			err:         nil,
 			dockerfiles: []string{"./Dockerfile", "./Job.dockerfile", "frontend/dockerfile"},
@@ -926,3 +1068,111 @@ func TestWorkspace_ListDockerfiles(t *testing.T) {
 		})
 	}
 }
+
+func TestWorkspace_read(t *testing.T) {
+	testCases := map[string]struct {
+		elems []string
+
+		copilotDir string
+		fs         func() afero.Fs
+
+		wantedData []byte
+		wantedErr  error
+	}{
+		"return error if file does not exist": {
+			elems: []string{"webhook", "manifest.yml"},
+
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				return fs
+			},
+
+			wantedErr: fmt.Errorf("file /copilot/webhook/manifest.yml does not exists"),
+		},
+		"read existing file": {
+			elems: []string{"webhook", "manifest.yml"},
+
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/webhook/", 0755)
+				f, _ := fs.Create("/copilot/webhook/manifest.yml")
+				defer f.Close()
+				f.Write([]byte("hello"))
+				return fs
+			},
+
+			wantedData: []byte("hello"),
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDir: tc.copilotDir,
+				fsUtils: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			data, err := ws.read(tc.elems...)
+
+			if tc.wantedErr == nil {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedData, data)
+			} else {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			}
+		})
+	}
+}
+
+func TestWorkspace_write(t *testing.T) {
+	testCases := map[string]struct {
+		elems []string
+
+		wantedPath string
+		wantedErr  error
+	}{
+		"create file under nested directories": {
+			elems:      []string{"webhook", "addons", "policy.yml"},
+			wantedPath: "/copilot/webhook/addons/policy.yml",
+		},
+		"create file under copilot directory": {
+			elems:      []string{legacyPipelineFileName},
+			wantedPath: "/copilot/pipeline.yml",
+		},
+		"return ErrFileExists if file already exists": {
+			elems:     []string{"manifest.yml"},
+			wantedErr: &ErrFileExists{FileName: "/copilot/manifest.yml"},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// GIVEN
+			fs := afero.NewMemMapFs()
+			utils := &afero.Afero{
+				Fs: fs,
+			}
+			utils.MkdirAll("/copilot", 0755)
+			utils.WriteFile("/copilot/manifest.yml", []byte{}, 0644)
+			ws := &Workspace{
+				workingDir: "/",
+				copilotDir: "/copilot",
+				fsUtils:    utils,
+			}
+
+			// WHEN
+			actualPath, actualErr := ws.write(nil, tc.elems...)
+
+			// THEN
+			if tc.wantedErr != nil {
+				require.EqualError(t, actualErr, tc.wantedErr.Error(), "expected the same error")
+			} else {
+				require.Equal(t, tc.wantedPath, actualPath, "expected the same path")
+			}
+		})
+	}
+}
